require('dotenv-expand')(require('dotenv').config({ path: 'dist/.env' }));
let mix = require('laravel-mix');
const cssNanoOptions = require('./src/config/cssNanoOptions');

/*
 *    Variables
-------------------------------------------------- */
const root = process.cwd();
const slug = process.env.SLUG;


mix
	.disableNotifications()
	.setPublicPath('dist/public_html')
	.setResourceRoot('dist/public_html/assets')
	.copy('src/templates', 'dist/templates')
	.copy('src/assets', 'dist/public_html/assets')
	.sass('src/styles/style.scss', `assets/css/${process.env.SLUG}.css`, {
		includePaths: [
			'node_modules',
			'src/styles'
		],
		importer: require('node-sass-glob-importer')()
	})
	.options({
    processCssUrls: false,
    postCss: [
			require("css-mqpacker")(),
			require('postcss-combine-duplicated-selectors'),
			require('autoprefixer'),
			require('cssnano')({
				preset: ["advanced", (mix.inProduction) ? cssNanoOptions.prod : cssNanoOptions.dev]
			})
    ],
    clearConsole: false
  })
	.js('src/scripts/controller.js', `assets/js/${process.env.SLUG}.js`)
	.sourceMaps()
	.extract()
	.browserSync({
		proxy: process.env.DEFAULT_SITE_URL,
		host: process.env.DEFAULT_SITE_URL.replace('https://', ''),
		open: 'external',
		https: {
			key: `src/config/kartos.dev.key`,
			cert: `src/config/kartos.dev.crt`
		},
		files: [
			`${process.env.DIST_JS}/**/*.js`,
			`${process.env.DIST_CSS}/*.css`,
			`${process.env.DIST_HTML}/**/*.twig`
		]
	});
