
if (tether === null || typeof(tether) !== "object") { var tether = new Object(); }

tether.methods = {},
tether.utilities = {};


var mattPlayer, brittPlayer, jaredPlayer;

function onYouTubeIframeAPIReady() {
	mattPlayer = new YT.Player('vidPlayerMatt', {
    videoId: 'LP2dm5P9E3E',
    events: {
      'onReady': tether.methods.onPlayerReadyMatt
    }
  });

	brittPlayer = new YT.Player('vidPlayerBritt', {
    videoId: 'VSzYZS7-nIo',
    events: {
      'onReady': tether.methods.onPlayerReadyBritt
    }
  });

  jaredPlayer = new YT.Player('vidPlayerJared', {
    videoId: 'K4d8cjEP4qA',
    events: {
      'onReady': tether.methods.onPlayerReadyJared
    }
  });
}



 /**
 * ==================================================
 *		Utilities
 *    @namespace tether.utilities
 * ==================================================
 */

tether.utilities = {

	/**
	 *  addCSS
	 *  Adds CSS files to the <head>.
	 *
	 *  @param:  {String} file - path to the CSS file.
	 *
	 */
	addCSS: function(file) {
		var css = document.createElement('link');
		css.rel = 'stylesheet';
		css.href = '/assets/' + file;
		document.getElementsByTagName('head')[0].appendChild(css);
	},



	/**
	 *  addJS
	 *  Adds JS files to the end of the <body>.
	 *
	 *  @param:  {String} file - path to the JS file.
	 *
	 */

	addJS: function(file) {
		var a = document.createElement('script');
		a.type = 'text/javascript';
		a.async = true;
		a.src = '//static.addtoany.com/menu/page.js';
		var s = document.getElementsByTagName('script')[0];
		s.parentNode.insertBefore(a, s);
	},



	/**
	 *  getFormattedDate
	 *  Takes the timestamp from getStories(), formats it, and wraps it in HTML.
	 *
	 *  @param:  {String} timestamp - The raw timestamp.
	 *  @return: {String} The corrected formatted timestamp, wrapped in HTML.
	 *
	 */

	getFormatedDate: function(timestamp) {
		var date, year, month, day, result, months;
		date = new Date(timestamp);
		if (date == 'Invalid Date') {
			console.log('invalid found');
			result = '<span class="saves-data-date" style="visibility: hidden">JAN 01, 1970</span>';
		} else {
			year = date.getFullYear();
			month = date.getMonth();
			day = ("0" + date.getDate()).slice(-2);
			result = '';
			months = ['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'];

			result  = '<span class="saves-data-date">';
			result += months[month];
			result += ' ';
			result += day;
			result += ', ';
			result += year;
			result += '</span>';
		}
		return result;
	},


	/**
	 *  getFormattedSaveNumber
	 *  Parses the "Save Number" from getStories(), formats it, and wraps it in HTML.
	 *
	 *  @param:  {String} base - The raw HTML string.
	 *  @return: {String} The corrected formatted "Save Number", wrapped in HTML.
	 *
	 */

	getFormattedSaveNumber: function(base) {
		var arr = base.split(','),
				saveNumSplit = arr[0].split(' '),
				result = '';

		result += '<span class="saves-data-number">';
		result += saveNumSplit[0];
		result += ' ';
		result += '<b>';
		result += saveNumSplit[1];
		result += '</b>';
		result += '</span>';

		return result;
	},



	/**
	 *  getFormattedName
	 *  Parses the officer name from getStories(), formats it, and wraps it in HTML.
	 *
	 *  @param:  {String} base - The raw HTML string.
	 *  @return: {String} The corrected formatted officer name, wrapped in HTML.
	 *
	 */

	getFormattedName: function(base) {
		var arr = base.split(',');
		return '<span class="saves-data-name">'+ arr[1].trim() +'</span>';
	},



	/**
	 *  formatStories
	 *  Loops through each returned "Saves Story", calls the formatters, and returns formatted HTML.
	 *
	 *  @param:  {Object} $items - The jQuery collection of raw "Saves Story" data.
	 *  @return: {String} The complete, compiled "Saves Story" data.
	 *
	 */

	formatStories: function($items) {
		var result = '';
		$items.each(function() {
			var $this = jQuery(this),
					date = $this.find('h5').text(),
					baseStr = $this.find('h4').text(),
					url = 'https://www.safariland.com' + $this.find('a').attr('href'),
					dateStr = '',
					numStr = '',
					nameStr = ''.
					locStr = '';

			/** --- Pull Date -------------------- */
			date = date.split(' ');
			dateStr = tether.utilities.getFormatedDate(date[0]);

			/** --- Pull Number -------------------- */
			numStr = tether.utilities.getFormattedSaveNumber(baseStr);

			/** --- Pull Name -------------------- */
			nameStr = tether.utilities.getFormattedName(baseStr);

			result += '<a href="'+ url +'">';
			result += '<p class="saves-data-item">\n';
			result += dateStr + '\n';
			result += numStr + '\n';
			result += nameStr + '\n';
			result += '</p>' + '\n';
			result += '</a>';
		});

		return result;
	},


	/**
	 *  modalOpen
	 *  Populates data in the modal and displays it.
	 *
	 *  @param:  {Object} e - Event data.
	 *  @param:  {Object} $this - A jQuery object of the clicked image.
	 *  @param:  {Object} modal - A collection of jQuery objects related to the modal.
	 *
	 */

	modalOpen: function(e, name) {
		e.preventDefault();
		var selectedModal;
		switch(name) {
			case 'Matt Hanlin':
				selectedModal = jQuery('.modal-matt');
				break;

			case 'Britt Sweeney':
				selectedModal = jQuery('.modal-britt');
				break;

			case 'Jared Reston':
				selectedModal = jQuery('.modal-jared');
				break;
		}
		$('.tet-page-header').addClass('raised');
		$('body').addClass('stop-scrolling');

		selectedModal.delay(500).fadeIn(500);

		jQuery(document).on('keyup', function(e) {
			if (e.keyCode == 27) {
				jQuery('.modal-close-button').trigger('click');
			}
		});

	},


	/**
	 *  modalClose
	 *  Removes data in the modal and hides it.
	 *
	 *  @param:  {Object} e - Event data.
	 *  @param:  {Object} $this - A jQuery object of the clicked image.
	 *  @param:  {Object} modal - A collection of jQuery objects related to the modal.
	 *
	 */

	modalClose: function(modal) {
		jQuery('.saves-featured-video-modal').fadeOut(800, function() {
			$('.tet-page-header').removeClass('raised');
			$('body').removeClass('stop-scrolling');
			jQuery(document).off('keyup');
		});
	}

};








/**
* ==================================================
*		Methods
*   @namespace tether.methods
* ==================================================
*/

tether.methods = {


	/**
	 *  loadAssets
	 *  Calls addCSS() and addJS().
	 *
	 *  @param:  {Array} files - Files to load.
	 *
	 */

	loadAssets: function(files) {
		for (var i = 0; i < files.length; i++) {
			var fileType = files[i].substring(0,2);
			if (fileType === "cs") {
				tether.utilities.addCSS(files[i]);
			} else if (fileType === "js") {
				tether.utilities.addJS(files[i]);
			}
		}
	},



	/**
	 *  extendFrame
	 *  Overrides the fixed-container on the page.
	 *
	 */

	extendFrame: function() {
		jQuery('#header .level-2').remove();
		jQuery('#main').removeClass('row');
	},



	/**
	 *  videoModal
	 *  Sets up the eventListeners for the "Featured Saves" video modal.
	 *
	 */

	videoModal: function() {
		var $item = jQuery('#savesFeaturedVideos ul li a'),
				$closeBtn = jQuery('.modal-close-button, .modal-background'),
				modal = {},
				player = '';

		modal = {
			'elem': {
				'container': jQuery('.saves-featured-video-modal'),
				'wrapper': jQuery('.saves-featured-video-modal').find('.video-wrapper'),
				//'placeholder': jQuery('.saves-featured-video-modal').find('.video-placeholder'),
				'player': jQuery('#vidPlayer'),
				'thumb': jQuery('.saves-featured-video-modal').find('.video-thumb'),
				'number': jQuery('.saves-featured-video-modal').find('.modal-number'),
				'name': jQuery('.saves-featured-video-modal').find('.modal-name'),
				'first_name': jQuery('.content-ad').find('.modal-first-name'),
				'location': jQuery('.saves-featured-video-modal').find('.modal-location')
			},
			'playerAPI': '',
			'duration': 500
		};

	},

	onPlayerReadyMatt: function(event) {


			console.log('Matt Ready');
			jQuery('#mattVideo a').on('click', function(e) {
				var name = jQuery(this).data('name');
				tether.utilities.modalOpen(e, name);
				event.target.playVideo();
			});

			jQuery('.modal-close-button').on('click', function() {
				tether.utilities.modalClose();
				event.target.pauseVideo().seekTo(0);
			});


	},


	onPlayerReadyBritt: function(event) {
			jQuery('#brittVideo a').on('click', function(e) {
				var name = jQuery(this).data('name');
				tether.utilities.modalOpen(e, name);
				event.target.playVideo();
			});

			jQuery('.modal-close-button').on('click', function() {
				tether.utilities.modalClose();
				event.target.pauseVideo().seekTo(0);
			});

	},


	onPlayerReadyJared: function(event) {

			jQuery('#jaredVideo a').on('click', function(e) {
				var name = jQuery(this).data('name');
				tether.utilities.modalOpen(e, name);
				event.target.playVideo();
			});

			jQuery('.modal-close-button').on('click', function() {
				tether.utilities.modalClose();
				event.target.pauseVideo().seekTo(0);
			});

	},




	/**
	 *  getStories
	 *  Scrapes Safariland.com for "Saves Stories"
	 *
	 */

	getStories: function() {
		var $storiesRaw = jQuery('#search-result-items .row');
		var formattedData = tether.utilities.formatStories($storiesRaw);
		jQuery('#savesData').find('img').remove();
		jQuery('#savesData').append(formattedData);
	},

	header_scroll: function(){
		self.header_height = jQuery('#header').outerHeight();

		jQuery(window).on('scroll', function(e){

			docTop = jQuery(document).scrollTop();

			if( docTop > self.header_height ){
				jQuery('.tet-page-header').addClass('fixed')
			}else{
				jQuery('.tet-page-header').removeClass('fixed')
			}
		})
	}
};


/**
 *  init
 *  Starts the script.
 *
 */

tether.init = (function(){


	$(document).ready( function(){

		var m = tether.methods,
			u = tether.utilities;

		m.extendFrame();
		m.videoModal();
		m.getStories();
		m.header_scroll();


			var hash = window.location.hash;

			if (hash) {
				switch(hash) {
					case '#britt':
						var target = jQuery('#brittVideo a');
						break;
					case '#matt':
						var target = jQuery('#mattVideo a');
						break;
					case '#jared':
						var target = jQuery('#jaredVideo a');
						break;
				}

				if (target) {
					setTimeout( function(){
						$('html, body').animate({
							scrollTop: $('#savesFeaturedVideos').offset().top - 98,
						}, 500);
						target.trigger('click');
						// jQuery('iframe#vidPlayer').on('load', function() {
						// 	jQuery('.video-thumb').trigger('click');
						// });
					}, 2500);
				}
			}


		jQuery('.mobile-menu-trigger').on('click', function(){
				var $target = jQuery(this),
					$menu = $target.parents('.tet-page-header-mobile')
					$nav = $menu.find('.mobile-campaign-navigation');

				if ($menu.hasClass('active')) {
					$nav.fadeOut(300);
					$menu.removeClass('active');
				} else {
					$menu.addClass('active');
					$nav.fadeIn(300);
				}
		});


		jQuery('.tint-loader').delay(2000).fadeOut( 500);
	})
}());


