var gulp = require('gulp'),
	cache = require('gulp-cache'),
	changed = require('gulp-changed'),
	cleanCSS = require('gulp-clean-css'),
	combinemq = require('gulp-combine-mq'),
	concat = require('gulp-concat'),
	concatcss = require('gulp-concat-css'),
	data = require('gulp-data'),
	del = require('del'),
	fs = require('fs'),
	git = require('gulp-git'),
	gulpif = require('gulp-if'),
	gutil = require('gulp-util'),
	htmlmin = require('gulp-htmlmin'),
	imagemin = require('gulp-imagemin'),
	jslint = require('gulp-jshint'),
	lazypipe = require('lazypipe'),
	livereload = require('gulp-livereload'),
	mustache = require('gulp-mustache'),
	open = require('gulp-open'),
	pngquant = require('imagemin-pngquant'),
	stylish = require('jshint-stylish'),
	path = require('path'),
	plumber = require('gulp-plumber'),
	prettify = require('gulp-prettify'),
	print = require('gulp-print'),
	rename = require('gulp-rename'),
	runSequence = require('run-sequence'),
	sass = require('gulp-sass'),
	sourcemaps = require('gulp-sourcemaps'),
	sprity = require('sprity'),
	spritySass = require('sprity-sass'),
	svg2png = require('gulp-svg2png'),
	svgSprite = require('gulp-svg-sprite'),
	swig = require('gulp-swig'),
	tap = require('gulp-tap'),
	uglify = require('gulp-uglify'),
	uncss = require('gulp-uncss'),
	zip = require('gulp-zip');

var paths = {
		source: {
			base: 	'_source/',
			content:'./_source/_media/content/',
			css: 	'_source/_media/sass/',
			fonts: 	'_source/_media/fonts/',
			plugins:'_source/_media/js/vendor/',
			js: 	'_source/_media/js/',
			img: 	'_source/_media/images/'
		},
		build: {
			base: 	'_build/',
			css: 	'_build/_media/css/',
			fonts: 	'_build/_media/fonts/',
			js: 	'_build/_media/js/',
			img: 	'_build/_media/images/',
		}
	};





/**
* ==================================================
*		Fonts
* ==================================================
*/
gulp.task('moveType', function() {
	var s = paths.source.fonts,
		b = paths.build.fonts;

	gulp.src([s + '/**'])
		.pipe(gulp.dest(b));
});

gulp.task('moveHtaccess', function() {
	var s = paths.source.base,
		b = paths.build.base;

	gulp.src([s + '/.htaccess'])
		.pipe(gulp.dest(b));
});

// gulp.task('moveMenuJS', function() {
// 	var s = paths.source.content,
// 		b = paths.build.js;

// 	gulp.src([s + '/menus.js'])
// 		.pipe(gulp.dest(b));
// });


/**
* ==================================================
*		Templates
* ==================================================
*/

function requireUncached( $module ) {
    delete require.cache[require.resolve( $module )];
    return require( $module );
}

/** --- Combine data -------------------- */
gulp.task('concatTemplateData', function() {
	var s = paths.source.content;

	//excluding content.js, join data files
	return gulp.src([s + '*.js', '!' + s +'content.js'])
		.pipe(plumber(function (error) {
			gutil.log(error.message);
			this.emit('end');
		}))
		.pipe(concat('content.js'))
		.pipe(gulp.dest(s));
});

gulp.task('processTemplates', function() {
	var s = paths.source.base,
		b = paths.build.base,
		//templates = [s + '**/*.html'],
		content = requireUncached(paths.source.content + 'content.js');
		//console.log(content);

	return gulp.src([s + '**/*.html', '!' + s +'_templates/**/*'])

		.pipe(plumber(function (error) {
			gutil.log(error.message);
			this.emit('end');
		}))
		.pipe(data(content))
		.pipe(print())
		.pipe(swig({
      		defaults: { cache: false }
    	}))
    	.pipe(prettify({
    		indent_size: 4,
			preserve_newlines: true,
    	}))
		.pipe(gulp.dest(b));
});


/**
* ==================================================
*		STYLES
* ==================================================
*/


/** --- Process Sass -------------------- */
gulp.task('processSass', function() {
	var s = paths.source.css,
		b = paths.build.css;

	return gulp.src(s + 'style.scss')
		.pipe(plumber(function (error) {
			gutil.log(error.message);
			this.emit('end');
		}))
		//.pipe(sourcemaps.init())
		.pipe(sass({outputStyle: 'expanded',indentedSyntax: true }).on('error', sass.logError))
		//.pipe(sourcemaps.write())
		//.pipe(concatcss('style.css'))
		//.pipe(combinemq({ beautify: true }))

		// .pipe(cleanCSS({
		// 		compatibility: 'ie9',
		// 		debug: true
		// 	}, function(details) {
		// 			console.log(details);
		// 			console.log(details.name + ': ' + details.stats.originalSize);
		// 			console.log(details.name + ': ' + details.stats.minifiedSize);
		// 	}))

		.pipe(gulp.dest(b));
});




/**
* ==================================================
*		JAVASCRIPT
* ==================================================
*/

/** --- Process Core JS Files -------------------- */
gulp.task('processCoreJs', function() {
	var s = paths.source.js,
		b = paths.build.js;
	
	return gulp.src([s + '*.js'])
		.pipe(plumber(function (error) {
			gutil.log(error.message);
			this.emit('end');
		}))
		.pipe(concat('tether.js'))
		.pipe(jslint())
		.pipe(jslint.reporter(stylish))
		//.pipe(uglify({ mangle: false }))
		.pipe(gulp.dest(b));
});


/** --- Process Plugin JS Files -------------------- */
gulp.task('processPluginJs', function() {
	var s = paths.source.js,
		b = paths.build.js;
	
	//move modernizr
	gulp.src([s + 'vendor/modernizr-custom.js'])
	.pipe(gulp.dest(b));

	//excluding modernizr, join plugins and move
	return gulp.src([s + 'vendor/*.js', '!' + s +'vendor/modernizr-custom.js'])
		.pipe(plumber(function (error) {
			gutil.log(error.message);
			this.emit('end');
		}))
		.pipe(concat('plugins.js'))
		//.pipe(uglify())
		.pipe(gulp.dest(b));
});


/**
* ==================================================
*		MEDIA
* ==================================================
*/


/** --- Compress Images -------------------- */
gulp.task('compressImages', function() {
	var s = paths.source.img,
		b = paths.build.img;

	return gulp.src([s + '**/*'])
	
		.pipe(plumber(function (error) {
			gutil.log(error.message);
			this.emit('end');
		}))
		.pipe(changed(b))
		.pipe(imagemin({
			progressive: true,
			svgoPlugins: [{removeViewBox: false}],
			use: [pngquant()]
		}))
		.pipe(gulp.dest(b));
});

// gulp.task('createSvgSprite', function() {
// 	return gulp.src([paths.source.img + 'sprites/svg/*.svg'])
// 		.pipe(plumber(function (error) {
// 			gutil.log(error.message);
// 			this.emit('end');
// 		}))
// 		.pipe(svgSprite({
// 			'dest': '.',
// 			'mode': {
// 				'css': {
// 					'dest': '.',
// 					'layout': 'vertical',
// 					'sprite': 'sprite-icons.svg',
// 					'bust': false,
// 					'render': {
// 						'scss': {
// 							'template': './_source/sass/vendor/svg-sprite/sprite-template-svg.scss',
// 							'dest': '../../sass/base/_sprite-svg.scss'
// 						}
// 					}
// 				}
// 			}
// 		}))
// 		.pipe(gulp.dest(paths.source.img + 'sprites/'));
// });


// gulp.task('convertSvgSpriteToPng', function() {
// 	return gulp.src([paths.source.img + 'sprites/sprite-icons.svg'])
// 		.pipe(plumber(function(error) {
// 			gutil.log(error.message);
// 			this.emit('end');
// 		}))
// 		.pipe(svg2png())
// 		.pipe(gulp.dest(paths.source.img + 'sprites/'));
// });


// gulp.task('processSprite', ['createSvgSprite', 'convertSvgSpriteToPng']);




/** --- Watch -------------------- */
gulp.task('watch', function(callback) {
	var s = paths.source,
		b = paths.build;
	
	/** --- Templates -------------------- */
	gulp.watch([s.content + '*.js', '!' + s.content +'content.js'], ['concatTemplateData']);
	gulp.watch([s.content +'content.js', s.base + '**/*.html'], ['processTemplates']);
	
	
	/** --- Styles -------------------- */
	gulp.watch([s.css + '**/*.scss'], ['processSass']);
	
	
	/** --- JavaScript -------------------- */
	gulp.watch([s.js + '*.js'], ['processCoreJs']);
	gulp.watch([s.js + 'vendor/*.js'], ['processPluginJs']);
			
	
	/** --- Images -------------------- */
	gulp.watch([s.img + '**/*.{png,jpg,gif,svg}'], ['compressImages']);
	
	
	/** --- Icons -------------------- */
	//gulp.watch([s.img + 'sprites/**'], ['processImages']);

});






/**
* ==================================================
*		CONTROLLER TASKS
* ==================================================
*/

/** --- Build -------------------- */
gulp.task('build', function(callback) {
	runSequence(
		//'processSprite',
		'compressImages',
		'processPluginJs',
		'processCoreJs',
		'processSass',
		'concatTemplateData',
		'processTemplates',
		'moveType',
		'moveHtaccess',
		callback
	);
});


/** --- Deploy -------------------- */
// gulp.task('deploy', function(callback) {
// 	runSequence(
// 		'build',
// 		'backup',
// 		'gitAdd',
// 		'gitPush',
// 		callback
// 	);
// });


/** --- Default -------------------- */
gulp.task('default', function(callback) {
	runSequence(
		'build',
		'watch',
		callback
	);
});