//Dust Particles Simulation by bionicoz based on
//Basic Particle Animation
//Author: Brandon John-Freso
$(function () {

    var W, H,
        canvas, ctx, //ctx stands for context and is the "curso" of our canvas element.
        particleCount = 400,
        particles = [], //this is an array which will hold our particles Object/Class
        contexts = [];

    W = window.innerWidth ;
    H = window.innerHeight ;

    var mouse = {
        x: 0, 
        y: 0,
        rx:0,
        ry:0,
        speed:45,
        delta:0
    };
    


    document.addEventListener('mousemove', function(e){ 
        
        mouse.x = e.clientX || e.pageX; 
        mouse.y = e.clientY || e.pageY;
        mouse.x-=W/2;
        mouse.y-=H/2;
      
    }, false);
  
    function randomNorm(mean, stdev) {
        return Math.abs(Math.round((Math.random()*2-1)+(Math.random()*2-1)+(Math.random()*2-1))*stdev)+mean;
    }

    //Setup particle class
    function Particle( ctx ) {
        //using hsl is easier when we need particles with similar colors
        this.ctx = ctx;
        this.h= 217; //parseInt(45);
        this.s= 41; //parseInt(40 * Math.random() + 30);
        this.l= 13; //parseInt(40 * Math.random() + 30);
        this.a=0.5*Math.random() ;
      
        this.color = "hsla("+ this.h +","+ this.s +"%,"+ this.l +"%,"+(this.a)+")";
        this.shadowcolor = "hsla("+ this.h +","+ this.s +"%,"+ this.l +"%,"+parseFloat(this.a-0.55)+")";
        
        this.x = Math.random() * W;
        this.y = Math.random() * H;
        this.direction = {
            "x": -1 + Math.random() * 2,
            "y": -1 + Math.random() * 2
        };
        //this.radius = 9 * ((Math.random()*2-1)+(Math.random()*2-1)+(Math.random()*2-1)+3);
        this.radius = randomNorm(.4,1.2);
        this.scale=0.8*Math.random()+0.5;
        this.rotation=Math.PI/4*Math.random();
      
        this.grad=this.ctx.createRadialGradient( this.x, this.y, this.radius, this.x, this.y, 0 );
        this.grad.addColorStop(0,this.color);
        this.grad.addColorStop(1,this.shadowcolor);
      
        this.vx = (2 * Math.random() + 4)*.01*this.radius;
        this.vy = (2 * Math.random() + 4)*.01*this.radius;
        
        this.valpha = 0.01*Math.random()-0.02;
        
        this.move = function () {
            this.x += this.vx * this.direction.x ;
            this.y += this.vy * this.direction.y ;
            this.rotation+=this.valpha;
            this.radius*= Math.abs((this.valpha*0.01+1));

        };
        this.changeDirection = function (axis) {
            this.direction[axis] *= -1;
            this.valpha *= -1;
        };
        this.draw = function () {
            this.ctx.save();
            this.ctx.translate(this.x+mouse.rx/-20*this.radius,this.y+mouse.ry/-20*this.radius);  
            this.ctx.rotate(this.rotation);  
            this.ctx.scale(1,this.scale);
            
            this.grad=this.ctx.createRadialGradient( 0, 0, this.radius, 0, 0, 0 );
            this.grad.addColorStop(1,this.color);
            //this.grad.addColorStop(0,this.shadowcolor);
            this.ctx.beginPath();
            this.ctx.fillStyle = this.grad;
            this.ctx.arc(0, 0, this.radius, 0, Math.PI * 2, false);
            this.ctx.fill();
            this.ctx.restore();
        };
        this.boundaryCheck = function () {
            if (this.x >= W*1.2) {
                this.x = W*1.2;
                this.changeDirection("x");
            } else if (this.x <= -W*0.2) {
                this.x = -W*0.2;
                this.changeDirection("x");
            }
            if (this.y >= H*1.2) {
                this.y = H*1.2;
                this.changeDirection("y");
            } else if (this.y <= -H*0.2) {
                this.y = -H*0.2;
                this.changeDirection("y");
            }
        };
    } //end particle class

    function clearCanvas() {
        $.each( contexts, function( i, val ){
            val.clearRect(0, 0, W, H);
        })
    } //end clear canvas

    function createParticles( ctx ) {
        for (var i = particleCount - 1; i >= 0; i--) {
            p = new Particle(ctx);
            particles.push(p);
        }
    } // end createParticles

    function drawParticles() {
        for (var i = particleCount - 1; i >= 0; i--) {
            p = particles[i];
            p.draw();
        }
    } //end drawParticles

    function redrawParticles() {
        for (var i = particles.length - 1; i >= 0; i--) {
            p = particles[i];
            p.draw();
        }
    } //end drawParticles

    function updateParticles() {
        for (var i = particles.length - 1; i >= 0; i--) {
            p = particles[i];
            p.move();
            p.boundaryCheck();
        }
    } //end updateParticles

    function initParticleSystem( i ) {
        createParticles(i);
        drawParticles();
    }

    function animateParticles() {
        clearCanvas();
        setDelta();
        update()
        redrawParticles();
        updateParticles();
        requestAnimationFrame(animateParticles);
    }
  
  
    function setDelta() {  
        this.now    =   (new Date()).getTime();  
        mouse.delta =   (this.now-this.then)/1000;  
        this.then   =   this.now;  
    }

    function update() {  
 
        if(isNaN(mouse.delta) || mouse.delta <= 0) { return; }  
     
        var distX   =   mouse.x - (mouse.rx),  
            distY   =   mouse.y - (mouse.ry);  

        if(distX !== 0 && distY !== 0) {          
     
            mouse.rx -=  ((mouse.rx - mouse.x) / mouse.speed); 
            mouse.ry -=  ((mouse.ry - mouse.y) / mouse.speed); 
             
        }   
      
    };

    $('.particle-frame canvas').each( function(i){

        canvas_id = $(this).attr('id')
        canvas = $( '#' + canvas_id ).get(0); //this "get(0) will pull the underlying non-jquery wrapped dom element from our selection
        canvas.width = W;
        canvas.height = H;

        

        ctx = canvas.getContext("2d"); // settng the context to 2d rather than the 3d WEBGL
        ctx.globalCompositeOperation = "lighter";
        contexts.push(ctx)

        initParticleSystem( ctx );
        requestAnimationFrame(animateParticles);
    })
    
});
