/**
 *  BrowserSync settings
 *
 *  @global
 *  @since 0.0.0
 *  @author Nick Snyder <nick@nicksnyder.is>
 *  @copyright Nick Snyder 2020
 */


/*
 *   Packages and variables
-------------------------------------------------- */
const ip = require('ip');


/*
 *   Class: BrowserSyncSettings
-------------------------------------------------- */
class BrowserSyncSettings {

	/**
	 *  Build a new collection of settings for BrowserSync.
	 *
	 *  @class
	 *  @param {object} config Global environmental settings
	 */
	constructor(config) {
		this.options = {
			cors: true,
			files: [
				`${config.dist.html}/**/*.html`,
				`${config.dist.css}/**/*.css`,
				`${config.dist.css}/fonts/**/*`,
				`${config.dist.js}/**/*.{js,vue}`
			],
			host: ip.address(),
			https: {
				cert: config.cert,
				key: config.key
			},
			injectChanges: true,
			logLevel: 'warn',
			logPrefix: `[ ${config.slug} ]`,
			notify: false,
			open: false,
			port: 3000,
			proxy: config.url,
			reloadOnRestart: false,
			watchEvents: [
				'add',
				'change',
				'unlink'
			]
		};
		return this.options;
	}
}

module.exports = BrowserSyncSettings;
