/**
 *  BrowserSync settings
 *
 *  @global
 *  @since 0.0.0
 *  @author Nick Snyder <nick@nicksnyder.is>
 *  @copyright Nick Snyder 2020
 */


/*
 *   Packages and variables
-------------------------------------------------- */
const ip = require('ip');


/*
 *   Class: BrowserSyncSettings
-------------------------------------------------- */
class BrowserSyncSettings {

	/**
	 *  Build a new collection of settings for BrowserSync.
	 *
	 *  @class
	 *  @param {object} config Global environmental settings
	 */
	constructor(config) {
		this.options = {
			cors: true,
			files: [
				`${config.dist.html}/**/*.{html,php}`,
				`${config.dist.css}/**/*.css`,
				`${config.dist.css}/fonts/**/*`,
				`${config.dist.js}/**/*.{js,vue}`,
				`${config.src.js}/**/*.{vue}`
			],
			host: ip.address(),
			https: {
				cert: './server.cert',
				key: './server.key',
			},

			injectChanges: true,
			logLevel: 'warn',
			logPrefix: `[ ${config.slug} ]`,
			notify: false,
			open: "local",
			server: {
				baseDir: "./dist",
				index: "index.html"
			},
			proxy: false,
			reloadOnRestart: false,
			watchEvents: [
				'add',
				'change',
				'unlink'
			]
		};
		return this.options;
	}
}

module.exports = BrowserSyncSettings;
