 /**
  *  Environment repository builder
  *
  *  @global
  *  @since 0.0.0
  *  @author Nick Snyder <nick@nicksnyder.is>
  *  @copyright Nick Snyder 2020
  */


/*
 *   Packages and variables
-------------------------------------------------- */
const pro = process;
const moment = require('moment');
require('dotenv-expand')(require('dotenv').config({path: `${pro.cwd()}/.env`}));


/*
 *   Class: Env
-------------------------------------------------- */
class Env {
	/**
	 *  Create a new instance of project data.
	 *
	 *  @class
	 *  @returns {object} An instance of project data.
	 */
	constructor() {
		this.env = pro.env;
		this.envOptions = this.buildEnvOptions();
		this.helpers = this.buildHelpers();

		return {
			...this.envOptions,
			...this.helpers
		};
	}

	/**
	 *  Build environment options from `npm` and `.env`.
	 *
	 *  @returns {object} An object containing environment options.
	 */
	buildEnvOptions() {
		return {
			backup: this.env.BACKUP_PATH,
			config: this.env.CONFIG_PATH,
			dist: {
				assets: this.env.DIST_ASSETS,
				audio: this.env.DIST_AUD,
				css: this.env.DIST_CSS,
				html: this.env.DIST_HTML,
				img: this.env.DIST_IMG,
				js: this.env.DIST_JS,
				media: this.env.DIST_MEDIA,
				video: this.env.DIST_VID
			},
			env: this.env.NODE_ENV,
			hasUnicode: this.env.npm_config_unicode,
			root: this.env.pwd,
			slug: this.env.PRJ_SLUG,
			src: {
				assets: this.env.SRC_ASSETS,
				audio: this.env.SRC_AUD,
				css: this.env.SRC_CSS,
				html: this.env.SRC_HTML,
				img: this.env.SRC_IMG,
				js: this.env.SRC_JS,
				video: this.env.SRC_VID
			},
			ssl: {
				cert: this.env.PRJ_CERT,
				key: this.env.PRJ_KEY
			},
			url: this.env.PRJ_URL
		};
	}

	/**
	 *  Creates non-vital helper data for the task runner.
	 *
	 *  @returns {object} A collection of helper data.
	 */
	buildHelpers() {
		return {
			utils: {
				datetime: {
					dayInMs: 86400000,
					today: {
						day: moment().format('DD'),
						hour: moment().format('HH'),
						iso: moment().format('YYYY-MM-DD_HHmm'),
						minute: moment().format('mm'),
						month: moment().format('MM'),
						second: moment().format('ss'),
						unix: moment().format('x'),
						week: moment().format('WW'),
						year: moment().format('YYYY-MM-DD')
					}
				}
			}
		};
	}
}

module.exports = new Env();
