/**
 *  CSS Nano settings
 *
 *  @global
 *  @since 0.0.0
 *  @author Nick Snyder <nick@nicksnyder.is>
 *  @copyright Nick Snyder 2020
 */

/*
 *   Class: Nano
-------------------------------------------------- */
class NanoSettings {

	/**
	 *  Create a collection of settings for CSS Nano.
	 *
	 *  @class
	 *  @param {object} config Global environmental settings
	 *  @returns {object} A collection of CSS Nano settings for either development or production, depending on the environment.
	 *
	 */
	constructor(config) {
		this.config = {};
		this.globals = {
			autoprefixer: true,
			calc: true,
			colormin: true,
			convertValues: false,
			discardComments: false,
			discardDuplicates: false,
			discardEmpty: true,
			mergeIdents: false,
			mergeLonghand: true,
			mergeRules: true,
			minifyFontValues: true,
			minifyGradients: true,
			normalizeCharset: true,
			normalizeDisplayValues: true,
			normalizePositions: true,
			normalizeRepeatStyle: true,
			normalizeString: true,
			normalizeTimingFunctions: true,
			normalizeUnicode: true,
			normalizeUrl: true,
			orderedValues: true,
			reduceIdents: false,
			reduceInitial: true,
			reduceTransforms: true,
			svgo: true,
			uniqueSelectors: true,
			zindex: true
		};
		this.config.development = this.optionsDevelopment(this.globals);
		this.config.production = this.optionsProduction(this.globals);
		return this.config[config.env];
	}

	/**
	 *  Create settings for development.
	 *
	 *  @returns {object} Development settings
	 */
	optionsDevelopment() {
		return {
			...this.globals,
			discardComments: false,
			discardOverridden: false,
			discardUnused: false,
			minifyParams: false,
			minifySelectors: false,
			normalizeWhitespace: false
		};
	}

	/**
	 *  Create settings for production.
	 *
	 *  @returns {object} Production settings
	 */
	optionsProduction() {
		return {
			...this.globals,
			discardComments: true,
			discardOverridden: true,
			discardUnused: true,
			minifyParams: true,
			minifySelectors: true,
			normalizeWhitespace: true
		};
	}
}

module.exports = NanoSettings;
