/**
 *  Controller script
 */



/*
 *   Imports
-------------------------------------------------- */
import axios from 'axios';
import Vue from 'vue';
import Vuex from 'vuex';
import VueNumeric from 'vue-numeric'

/*
 *   Variables and settings
-------------------------------------------------- */

/** Axios settings. */
axios.defaults.headers.post['Content-Type'] ='application/json;charset=utf-8';
axios.defaults.headers.post['Access-Control-Allow-Origin'] = '*';

/** Enable Vuex. */
Vue.use(Vuex);

/** Enable VueNumeric. */
Vue.use(VueNumeric)


/** Add vendor files to window object as fail-safe. */
window.axios = axios;
window.Vue = Vue;
window.Vuex = Vuex;

Vue.config.productionTip = true;


/*
 *   Load components
-------------------------------------------------- */
require('./components/components');

const store = new Vuex.Store({

	state: {
		leagueAverageSalary: 0,
		missingSalaryNum: 0,
		leagueMinimumSalary: 507500,
		playerSalaryLastSeason: 0,
		estimatedPlayerWAR: 0.5,
		estimatedDollarsPerWAR: 6000000,
		qualifyingOffer: 0,
	},

	mutations: {
		updateInputValue(state, obj) {
			state[obj.target] = obj.value;
		},
		updateInputValueInt(state, obj) {
			state[obj.target] = obj.value;
		}
	}
});

/*
 *   Start application
-------------------------------------------------- */
new Vue({
  el: '#qoCalc',
	store,

	mounted() {
			this.checkPlayerSalaryLastSeason();
			this.getSalaryData();
			this.formatCurrency();
	},



	methods: {

		checkPlayerSalaryLastSeason() {
			if (!this.$store.state.playerSalaryLastSeason) {
				this.$store.commit('updateInputValue', {
					target: 'playerSalaryLastSeason',
					value: this.$store.state.leagueMinimumSalary
				});
			}
		},


		formatCurrency(num) {
			// @source Internet search.
			// @source https://stackoverflow.com/questions/149055/how-to-format-numbers-as-currency-string
			const formatCurrency = new Intl.NumberFormat('en-US', {
				style: 'currency',
				currency: 'USD'
			});

			return formatCurrency.format(num);
		},

		getSalaryData() {
			axios.get(`${window.location.origin}/scraper.php`)
					.then(resp => {
						this.$store.state.qualifyingOffer = resp.data.salary['qualifying_offer'];
						this.$store.state.leagueAverageSalary = resp.data.salary['league_average'];
						this.$store.state.missingSalaryNum = resp.data.salary['missing_data_count'];

					});
		},
		updateInputValue(e) {
			this[e.target.id] = e.target.value;
		}
	}
});



// const html = axios.get(`${window.location.origin}/scraper.php`).then(
// 	resp => {
//         let result = resp.data;
//         console.log(result);
//   });
