/**
 *   Task Runner
 */


/*
 *    Packages and variables
 * --------------------------------------------------
 */

/** --- NPM Packages --------- */
const mix = require('laravel-mix');
const postCssNormalize = require('postcss-normalize');
const postCssAutoprefixer = require('autoprefixer');
const	postCssNoImportant = require('postcss-no-important');
const postCssPresetAdvanced = require('cssnano-preset-advanced');
const sassGlobImporter = require('node-sass-glob-importer');


/** --- Configuration classes --------- */
const Config = require('./src/config/classes/class.Env.js');
const BrowserSyncSettings = require('./src/config/classes/class.BrowserSyncAlt.js');
const NanoSettings = require('./src/config/classes/class.Nano.js');


/** --- Variables --------- */
const isProd = mix.inProduction();


/*
 *    Runner workflow
 *--------------------------------------------------
 */

mix
	// Path to assets; where mix-manifest.json will go.
	.setPublicPath(Config.dist.assets)

	// Path to assets from @webroot; think URLs.
	.setResourceRoot('/dist/assets')

	// Disable success notifications; show error notifications.
	.disableSuccessNotifications()

	// Set webpack options
	.webpackConfig({
		devtool: (isProd) ? false : 'source-map'
	})

	// Set advanced options
	.options({
		clearConsole: false,
		cssNano: {preset: ['advanced', new NanoSettings(Config)] },
		postCss: [
			postCssNormalize,
			postCssAutoprefixer,
			postCssNoImportant,
			postCssPresetAdvanced
		],
		processCssUrls: false,
		terser: {
			terserOptions: {
				compress: {},
				ecma: 8,
				ie8: false,
				keep_classnames: false,
				keep_fnames: false,
				mangle: true,
				module: false,
				nameCache: null,
				output: null,
				parse: {},
				safari10: false,
				toplevel: false,
				warnings: 'verbose'
			}
		}
	})




	// Process template file(s).
	.copy(Config.src.html, Config.dist.html)

	// Process asset files.
	.copy(Config.src.img, Config.dist.img)
	.copy(Config.src.audio, Config.dist.audio)
	.copy(Config.src.video, Config.dist.video)

	// Process styles.
	.sass(`${Config.src.css}/styles.scss`, `${Config.dist.css}/${Config.slug}.css`, {
		sassOptions: {
			importer: sassGlobImporter(),
			includePaths: [
				'node_modules',
				'assets/styles'
			]
		}
	})

	// Process JavaScript controller.
	.js(`${Config.src.js}/controller.js`, `${Config.dist.js}/${Config.slug}.js`)

	// Create source maps.
	.sourceMaps()

	// Extract vendor files.
	.extract()

	// If applicable, run BrowserSync.
	.browserSync(new BrowserSyncSettings(Config));


/*
 *    Production only
 *--------------------------------------------------
 */
if (isProd) {
	mix.version();
}
