<?php
/**
 * Timber starter-theme
 * https://github.com/timber/starter-theme
 *
 * @package  WordPress
 * @subpackage  Timber
 * @since   Timber 0.1
 */

/**
 * If you are installing Timber as a Composer dependency in your theme, you'll need this block
 * to load your dependencies and initialize Timber. If you are using Timber via the WordPress.org
 * plug-in, you can safely delete this block.
 */
$composer_autoload = __DIR__ . '/vendor/autoload.php';
if ( file_exists($composer_autoload) ) {
	require_once( $composer_autoload );
	$timber = new Timber\Timber();
}

/**
 * This ensures that Timber is loaded and available as a PHP class.
 * If not, it gives an error message to help direct developers on where to activate
 */
if ( ! class_exists( 'Timber' ) ) {

	add_action( 'admin_notices', function() {
		echo '<div class="error"><p>Timber not activated. Make sure you activate the plugin in <a href="' . esc_url( admin_url( 'plugins.php#timber' ) ) . '">' . esc_url( admin_url( 'plugins.php' ) ) . '</a></p></div>';
	});

	add_filter('template_include', function( $template ) {
		return get_stylesheet_directory() . '/static/no-timber.html';
	});
	return;
}

/**
 * Sets the directories (inside your theme) to find .twig files
 */
Timber::$dirname = array( 'templates', 'views', 'vita', 'vita/-' );

/**
 * By default, Timber does NOT autoescape values. Want to enable Twig's autoescape?
 * No prob! Just set this value to true
 */
Timber::$autoescape = false;


/**
 * We're going to configure our theme inside of a subclass of Timber\Site
 * You can move this to its own file and include here via php's include("MySite.php")
 */
class StarterSite extends Timber\Site {

	public static $dataAttributes = ['data', 'data-ng', 'ng', 'aria'];
	public static $attributeOrder = [
		'type',
		'id',
		'class',
		'name',
		'value',
		'href',
		'src',
		'srcset',
		'form',
		'action',
		'method',
		'selected',
		'checked',
		'readonly',
		'disabled',
		'multiple',
		'size',
		'maxlength',
		'width',
		'height',
		'rows',
		'cols',
		'alt',
		'title',
		'rel',
		'media'
	];

	/** Add timber support. */
	public function __construct() {
		add_action( 'after_setup_theme', array( $this, 'theme_supports' ) );
		add_filter( 'timber/context', array( $this, 'add_to_context' ) );
		add_filter( 'timber/twig', array( $this, 'add_to_twig' ) );
		add_action( 'init', array( $this, 'register_post_types' ) );
		add_action( 'init', array( $this, 'register_taxonomies' ) );
		parent::__construct();
	}
	/** This is where you can register custom post types. */
	public function register_post_types() {

	}
	/** This is where you can register custom taxonomies. */
	public function register_taxonomies() {

	}

	/** This is where you add some context
	 *
	 * @param string $context context['this'] Being the Twig's {{ this }}.
	 */
	public function add_to_context( $context ) {

		$today = getdate();

		$context['foo'] = 'bar';
		$context['stuff'] = 'I am a value set in your functions.php file';
		$context['notes'] = 'These values are available everytime you call Timber::context();';
		$context['menu'] = array(
			'primary' => new Timber\Menu('Primary'),
			'secondary' => new Timber\Menu('Secondary'),
			'legal' => new Timber\Menu('Legal')
		);

		$context['today'] = array(
			'year' => $today['year'],
			'unix' => $today['0']
		);



		$context['site'] = $this;
		$context['env'] = getenv('ENVIRONMENT');
		$content['theme'] = array(
			'slug' => getenv('PRJ_SLUG'),
			'url' => getenv('PRJ_URL'),
			'code' => getenv('PRJ_CODE')
		);




		return $context;
	}

	public function theme_supports() {
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5', array(
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		/*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support(
			'post-formats', array(
				'aside',
				'image',
				'video',
				'quote',
				'link',
				'gallery',
				'audio',
			)
		);

		add_theme_support( 'menus' );
	}

	/** This Would return 'foo bar!'.
	 *
	 * @param string $text being 'foo', then returned 'foo bar!'.
	 */
	public function myfoo( $text ) {
		$text .= ' bar!';
		return $text;
	}

	public static function encode($content, $doubleEncode = true) {
  	return htmlspecialchars($content, ENT_QUOTES | ENT_SUBSTITUTE, 'UTF-8', $doubleEncode);
  }


	protected static function handleJsonError($lastError)
    {
        if ($lastError === JSON_ERROR_NONE) {
            return;
        }
        $availableErrors = [];
        foreach (static::$jsonErrorMessages as $const => $message) {
            if (defined($const)) {
                $availableErrors[constant($const)] = $message;
            }
        }
        if (isset($availableErrors[$lastError])) {
            throw new InvalidArgumentException($availableErrors[$lastError], $lastError);
        }
        throw new InvalidArgumentException('Unknown JSON encoding/decoding error.');
    }

		protected static function processData($data, &$expressions, $expPrefix)
    {
        if (is_object($data)) {
            if ($data instanceof JsExpression) {
                $token = "!{[$expPrefix=" . count($expressions) . ']}!';
                $expressions['"' . $token . '"'] = $data->expression;
                return $token;
            } elseif ($data instanceof \JsonSerializable) {
                return static::processData($data->jsonSerialize(), $expressions, $expPrefix);
            } elseif ($data instanceof Arrayable) {
                $data = $data->toArray();
            } elseif ($data instanceof \SimpleXMLElement) {
                $data = (array) $data;
            } else {
                $result = [];
                foreach ($data as $name => $value) {
                    $result[$name] = $value;
                }
                $data = $result;
            }
            if ($data === []) {
                return new \stdClass();
            }
        }
        if (is_array($data)) {
            foreach ($data as $key => $value) {
                if (is_array($value) || is_object($value)) {
                    $data[$key] = static::processData($value, $expressions, $expPrefix);
                }
            }
        }
        return $data;
    }


	public static function encodeHtml($value, $options = 320)
    {
        $expressions = [];
        $value = static::processData($value, $expressions, uniqid('', true));
        set_error_handler(function () {
            static::handleJsonError(JSON_ERROR_SYNTAX);
        }, E_WARNING);
        $json = json_encode($value, $options);
        restore_error_handler();
        static::handleJsonError(json_last_error());
        return $expressions === [] ? $json : strtr($json, $expressions);
    }


	public static function cssStyleFromArray(array $style) {
        $result = '';
        foreach ($style as $name => $value) {
            $result .= "$name: $value; ";
        }
        // return null if empty to avoid rendering the "style" attribute
        return $result === '' ? null : rtrim($result);
  }




	public function render_tag_attributes($attributes) {
		if (count($attributes) > 1) {
            $sorted = [];
            foreach (static::$attributeOrder as $name) {
                if (isset($attributes[$name])) {
                    $sorted[$name] = $attributes[$name];
                }
            }
            $attributes = array_merge($sorted, $attributes);
        }
        $html = '';
        foreach ($attributes as $name => $value) {
            if (is_bool($value)) {
                if ($value) {
                    $html .= " $name";
                }
            } elseif (is_array($value)) {
                if (in_array($name, static::$dataAttributes)) {
                    foreach ($value as $n => $v) {
												if ($v) {
	                        if (is_array($v)) {
	                            $html .= " $name-$n='" . static::encodeHtml($v) . "'";
	                        } else {
	                            $html .= " $name-$n=\"" . static::encode($v) . '"';
	                        }
												}
                    }
                } elseif ($name === 'class') {
                    if (empty($value)) {
                        continue;
                    }
                    $html .= " $name=\"" . static::encode(implode(' ', $value)) . '"';
                } elseif ($name === 'style') {
                    if (empty($value)) {
                        continue;
                    }
                    $html .= " $name=\"" . static::encode(static::cssStyleFromArray($value)) . '"';
                } else {
                    $html .= " $name='" . static::encodeHtml($value) . "'";
                }
            } elseif ($value !== null) {
                $html .= " $name=\"" . static::encode($value) . '"';
            }
        }
        return $html;
	}


	public function render_svg($url) {
		$doc_root = $_SERVER['DOCUMENT_ROOT'];



		if (!strpos($url, "/wp-content/uploads/")) {
			$url = get_template_directory_uri() . "/{$url}";
		}

		$url = static::sanitize_url_path($url);
		echo file_get_contents("{$doc_root}/{$url}");
	}

	public function sanitize_url_path($url) {
		$prefixes = array(
			'//',
			'http://',
			'https://',
			'//www.',
			'http://www.',
			'https://www.'
		);

		$url = str_replace($prefixes, '//', $url);
		$url_pattern = '/(\/\/femaleforwardtogether.)(test|com|cognitionstudio.com)(?:(:\d*))?\//';
		return preg_replace($url_pattern, '', $url);
	}





	/** This is where you can add your own functions to twig.
	 *
	 * @param string $twig get extension.
	 */

	public function add_to_twig( $twig ) {
		$twig->addExtension( new Twig_Extension_StringLoader() );
		$twig->addFilter( new Twig_SimpleFilter( 'myfoo', array( $this, 'myfoo' ) ) );
		$twig->addFunction( new Timber\Twig_Function( 'attr',  array( $this, 'render_tag_attributes' ) ) );
		$twig->addFunction( new Timber\Twig_Function( 'svg',  array( $this, 'render_svg' ) ) );
		return $twig;
	}



}

new StarterSite();



/*
 *    ACF Options page
 * -------------------------------------------------- */
require_once(__DIR__ . '/functions/acf-options-page.php');


/*
 *    Mime types
 * -------------------------------------------------- */
require_once(__DIR__ . '/functions/custom-mime-types.php');


/*
 *    Custom post types
 * -------------------------------------------------- */

/** --- Data sets ------ */
require_once(__DIR__ . '/functions/custom-post-type-datasets.php');

/** --- Partners ------ */
require_once(__DIR__ . '/functions/custom-post-type-partners.php');
