const fs = require('fs');
const {exec} = require('child_process');

/**
 *   Modernizr
 *   Creates a Mix-specific class that builds a custom Modernizr file.
 *   @class
 */
class Modernizr {
	/**
	 *   constructor
	 *   @param {String} filepath The file path to the Modernizr build file.
	 */
	constructor(filepath, config) {
		this.config = config;
		this.filepath = filepath;
		this.fileExists = fs.existsSync(filepath);
		this.configPath = `${config.src.config}/runner/config.customizr.json`;
		this.maxAgeInDays = 7;
		this.isStale = false;

		if (this.fileExists) {
			this.readFile();
		}
	}


	/**
	 *   build
	 * 	 Use customizr to build a custom Modernizr file.
	 */
	build() {
		exec(`$PWD/node_modules/.bin/customizr -c $PWD/${this.configPath};`, (err, stdout) => {
			if (err) {
				console.error(err);
				return;
			}
			console.log(stdout);
		});
	}


	/**
	 *   readFile
	 * 	 Reads current Modernizr file to determine age; will test against the user-defined maximum age.
	 */
	readFile() {
		const stats = fs.statSync(this.filepath);
		if (((this.config.utils.datetime.today.unix - Date.parse(stats.birthtime)) / (this.config.utils.datetime.dayInMs)) >= this.maxAgeInDays) {
			this.isStale = true;
		}
	}
}


module.exports = Modernizr;
