import MediaQueries from './MediaQueries';
import enquire from 'enquire.js';


export default class BootLoader {
	constructor() {
		this.isDesktop = window.matchMedia(MediaQueries.desktop.mq).matches;
		this.mobileMenu = null;
		this.mobileFirstRun = true;
	}

	/** --- Getters --------- */
	get mobileMenu() {
		return this._mobileMenu;
	}

	get mobileFirstRun() {
		return this._mobileFirstRun;
	}


	/** --- Setters --------- */
	set mobileMenu(value) {
		this._mobileMenu = value;
	}

	set mobileFirstRun(value) {
		this._mobileFirstRun = value;
	}


	/** --- Static Methods --------- */
	createMobileListener(self) {
		enquire.register('screen and (max-width: 540px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = el.dataset.heightMobile;
					el.style.height = dynHeight;
				});
			}
		});

		enquire.register('screen and (min-width: 541px) and (max-width: 560px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = Number(el.dataset.heightMobile.replace('px', ''));
					el.style.height = `${dynHeight + 15}px`;
				});
			}
		});

		enquire.register('screen and (min-width: 561px) and (max-width: 600px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = Number(el.dataset.heightTablet.replace('px', ''));
					el.style.height = `${dynHeight - 100}px`;
				});
			}
		});

		enquire.register('screen and (min-width: 601px) and (max-width: 670px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = Number(el.dataset.heightTablet.replace('px', ''));
					el.style.height = `${dynHeight - 30}px`;
				});
			}
		});

		enquire.register('screen and (min-width: 671px) and (max-width: 799px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = Number(el.dataset.heightTablet.replace('px', ''));
					el.style.height = `${dynHeight}px`;
				});
			}
		});


		enquire.register('screen and (min-width: 800px) and (max-width: 910px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = el.dataset.heightTabletLarge;
					el.style.height = dynHeight;
				});
			}
		});

		enquire.register('screen and (min-width: 911px) and (max-width: 1023px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = Number(el.dataset.heightTabletLarge.replace('px', ''));
					el.style.height = `${dynHeight + 45}px`;
				});
			}
		});

		enquire.register('screen and (min-width: 1024px) and (max-width: 1215px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = Number(el.dataset.heightDesktop.replace('px', ''));
					el.style.height = `${dynHeight - 50}px`;
				});
			}
		});


		enquire.register('screen and (min-width: 1216px)', {
			match() {
				const $img = document.querySelectorAll('.survey-results-image');
				$img.forEach((el) => {
					const dynHeight = el.dataset.heightDesktop;
					el.style.height = dynHeight;
				});
			}
		});

		enquire.register(`screen and (max-width: ${MediaQueries.desktop.num - 1}px)`, {
			deferSetup: self.isDesktop,
			match() {
				const $partners = document.querySelectorAll('.partner');
				if ($partners.length) {
					$partners.forEach((el) => {
						const partnerLogo = el.querySelector('.partner-logo');
						const partnerRole = el.querySelector('.partner-role');
						partnerLogo.addEventListener('click', (el) => {
							const close = partnerRole.querySelector('.partner-role-close');
							partnerRole.style.display = 'block';
							document.querySelector('body').classList.add('no-scroll');
							close.addEventListener('click', (event) => {
								partnerRole.style.display = 'none';
								document.querySelector('body').classList.remove('no-scroll');
							});
						});
					});
				}


				if (!self.mobileFirstRun) {
					self.mobileFirstRun = false;
				}
			},
			setup() {
				import(/* webpackChunkName: "chunks/MobileMenu" */'./../modules/MobileMenu.js')
					.then((module) => {
						self.mobileMenu = module;
						self.mobileMenu.init();
						self.firstRun = false;
					});
			},
			unmatch() {
				const $partners = document.querySelectorAll('.partner');
				if ($partners.length) {
					$partners.forEach((el) => {
						el.querySelector('.partner-logo').removeEventListener('click');
					});
				}
			}
		}, true);
	}

	createWidont() {
		const $headlines = document.querySelectorAll('h1, h2, h3, h4, h5, h6');
		$headlines.forEach((el) => {
			el.innerHTML = el.innerHTML.replace(/([^\s])\s+([^\s]+)\s*$/, '$1&nbsp;$2');
		});
	}

	createDatasets(self) {
		if (document.querySelector('body').classList.contains('home')) {
			import(/* webpackChunkName: "chunks/Datasets" */'./../modules/Datasets.js')
				.then((module) => {
					module.init();
				});

			import(/* webpackChunkName: "chunks/SmoothScrolls" */'./../modules/SmoothScrolls.js')
				.then((module) => {
					module.init();
				});
		}
	}


	/** --- Public Methods --------- */
	init() {
		this.createMobileListener(this);
		this.createWidont();
		this.createDatasets(this);
	}
}
