import Bootloader from './-/helpers/Bootloader';



const Boot = new Bootloader();


/*
 *    Bootloader
 *--------------------------------------------------
 */

Boot.init();


const cookie = {
	get(cookie) {
		const name = `${cookie}=`;
		const allCookieArray = document.cookie.split(';');
		for (let i = 0; i < allCookieArray.length; i++) {
			const temp = allCookieArray[i].trim();
			if (temp.indexOf(name) == 0) { return temp.substring(name.length, temp.length); }
		}
		return '';
	},

	set(name, value, days) {
		const date = new Date();
		date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
		document.cookie = `${name}=${value}; expires=${date.toGMTString()}`;
	}
};



/*
 *    Commitment to Privacy
 *--------------------------------------------------
 */

const toast = document.querySelector('.ctp-toast');
const toastView = document.querySelector('.toast-view');
const toastClose = document.querySelector('.toast-close');

const ctpDrawer = document.querySelector('.ctp-drawer');
const ctpClose = document.querySelector('.ctp-drawer-close');


toastView.addEventListener('click', (event) => {
	ctpDrawer.classList.add('is-active');
	event.preventDefault();
});

toastClose.addEventListener('click', (event) => {
	toast.classList.add('is-closed');
	cookie.set('privacy-toast-closed', true, 30);
	event.preventDefault();
});


ctpClose.addEventListener('click', (event) => {
	ctpDrawer.classList.remove('is-active');
	event.preventDefault();
});

if (cookie.get('privacy-toast-closed')) {
	toast.style.display = 'none';
	toast.classList.add('is-closed');
}



/*
 *    Reach Out
 *--------------------------------------------------
 */
const submitButton = document.getElementById('reachOutSubmit');
const agreeCheck = document.querySelector('[name="agree[]"]');

if (submitButton) {
	document.addEventListener('DOMContentLoaded', () => {
		submitButton.disabled = true;
		agreeCheck.addEventListener('change', () => {
			if (agreeCheck.checked) {
				submitButton.disabled = false;
			} else {
				submitButton.disabled = true;
			}
		});
	});
}

/*
 *    Form
 *--------------------------------------------------
 */

if (document.querySelector('body').classList.contains('page-id-49')) {
	document.querySelector('form.wpcf7-form').addEventListener('submit', (event) => {
		event.preventDefault();
		window.setTimeout(() => {
			submitButton.disabled = true;
			agreeCheck.checked = false;
		}, 1000);
	});
}



/*
 *    Email address picker
 *--------------------------------------------------
 */

if (document.querySelector('body').classList.contains('page-id-49')) {
	const destEmail = document.querySelector('input[name=dest-email]');
	const radioButtons = document.querySelectorAll('input[type=radio]');

	destEmail.parentElement.parentElement.style.display = 'none';


	radioButtons.forEach((el) => {
		el.addEventListener('change', () => {
			if (el.value === 'Media') {
				destEmail.value = 'media@myovant.com';
			} else {
				destEmail.value = 'femaleforward@myovant.com';
			}

			console.log(destEmail.value);
		});
	});
}


/*
 *    Skinny header
 *--------------------------------------------------
 */

let lastScroll = 0;
let ticking = false;
let scrollPos = 0;
const body = document.querySelector('body');

function toggleMenuTimerDelay() {
	document.querySelectorAll('.main-header').forEach((el) => {
		el.classList.toggle('clear-timer');
	});
}


function checkUserScrollPosition(y) {
	if (y > 385 && (!body.classList.contains('has-scrolled'))) {
		body.classList.add('has-scrolled');
		window.setTimeout(toggleMenuTimerDelay, 600);
	}

	if (y < 385 && (body.classList.contains('has-scrolled'))) {
		body.classList.remove('has-scrolled');
		toggleMenuTimerDelay();
	}
}

function checkUserScrollDirection(scrollPos) {
	if (((document.body.getBoundingClientRect()).top > scrollPos) && body.classList.contains('has-scrolled')) {
		if (!body.classList.contains('scrolling-up')) {
			body.classList.add('scrolling-up');
		}
	} else if (body.classList.contains('scrolling-up')) {
		body.classList.remove('scrolling-up');
	}
}


window.addEventListener('scroll', (event) => {
	checkUserScrollDirection(scrollPos);
	if (!ticking) {
		window.requestAnimationFrame(() => {
			checkUserScrollPosition(lastScroll);
			ticking = false;
		});
		ticking = true;
	}
	lastScroll = window.pageYOffset;
	scrollPos = (document.body.getBoundingClientRect()).top;
});
