/**
 *   Task Runner
 */


/*
 *    Packages and variables
 * --------------------------------------------------
 */

/** --- NPM Packages --------- */
const ChunkRenamePlugin = require('webpack-chunk-rename-plugin');
const mix = require('laravel-mix');
const postCssNormalize = require('postcss-normalize');
const postCssAutoprefixer = require('autoprefixer');
const postCssFontMagician = require('postcss-font-magician');
const	postCssNoImportant = require('postcss-no-important');
const postCssPacker = require('css-mqpacker');
const postCssPresetAdvanced = require('cssnano-preset-advanced');
const postCssSortCssMq = require('sort-css-media-queries');
const postCssSprites = require('postcss-sprites');

const sassGlobImporter = require('node-sass-glob-importer');



/** --- Configuration classes --------- */
const Config = require('./src/config/runner/classes/class.Env.js');
const Nano = require('./src/config/runner/classes/class.Nano.js');


/** --- Variables --------- */
const projectFonts = require('./src/styles/vita/01-atoms/theme/projectFonts.json');
const isProd = mix.inProduction;


/*
 *    Runner workflow
 *--------------------------------------------------
 */

mix

/** Path to assets; where mix-manifest.json will go. */

	.setPublicPath(`./${Config.dist.assets}/`)

	// Disable success notifications; show error notifications.
	.disableNotifications()

	// Set webpack options
	.webpackConfig({
		devtool: (isProd) ? false : 'source-map',

		output: {
			chunkFilename: 'js/[name].js',
			filename: '[name].js',
			publicPath: `/wp-content/themes/${Config.slug}/assets/`
		},
		plugins: [
			new ChunkRenamePlugin({
				'/js/vendor': '/js/vendor.js',
				initialChunksWithEntry: true
			})
		]
	})

	// Set advanced options
	.options({
		clearConsole: false,
		cssNano: {
			preset: [
				'advanced', new Nano(Config)
			]
		},
		postCss: [
			postCssFontMagician(projectFonts),
			postCssSprites({
				spritePath: `${Config.dist.img}/sprites`,
				stylesheetPath: Config.dist.css
			}),
			postCssNormalize,
			postCssAutoprefixer,
			postCssNoImportant,
			postCssPacker({sort: postCssSortCssMq}),
			postCssPresetAdvanced
		],
		processCssUrls: false,
		terser: {
			terserOptions: {
				compress: {},
				ecma: 8,
				ie8: false,
				mangle: true,
				module: false,
				nameCache: null,
				output: null,
				parse: {},
				safari10: false,
				toplevel: false,
				warnings: 'verbose'
			}
		}
	})

	// Process styles.
	.sass(`${Config.src.css}/styles.scss`, `${Config.dist.css}/${Config.slug}.css`, {
		importer: sassGlobImporter(),
		includePaths: [
			'node_modules', 'src/styles'
		]
	})
	// Create source maps.
	.sourceMaps();



/*
 *    Production only
 *--------------------------------------------------
 */
if (isProd) {
	mix.version();
}
