/**
 *   Task Runner
 */


/*
 *    Packages and variables
 * --------------------------------------------------
 */

/** --- NPM Packages --------- */
const ChunkRenamePlugin = require('webpack-chunk-rename-plugin');
const mix = require('laravel-mix');

/** --- Configuration classes --------- */
const Config = require('./src/config/runner/classes/class.Env.js');
const Mod = require('./src/config/runner/classes/class.Modernizr.js');
const BS = require('./src/config/runner/classes/class.BrowserSync.js');


/** --- Variables --------- */
const isProd = mix.inProduction;


/*
 *    Runner workflow
 *--------------------------------------------------
 */

mix

/** Path to assets; where mix-manifest.json will go. */

	.setPublicPath(`./${Config.dist.assets}/`)


/*
 * Path to assets from @webroot; think URLs.
 * .setResourceRoot(`${Config.url}/wp-content/themes/${Config.slug}/assets/`)
 */

	// Disable success notifications; show error notifications.
	.disableSuccessNotifications()

	// Set webpack options
	.webpackConfig({
		devtool: (isProd) ? false : 'source-map',

		output: {
			chunkFilename: 'js/[name].js',
			filename: '[name].js',
			publicPath: `/wp-content/themes/${Config.slug}/assets/`
		},
		plugins: [
			new ChunkRenamePlugin({
				'/js/vendor': '/js/vendor.js',
				initialChunksWithEntry: true
			})
		]
	})

/*
 * TODO: Test the file chunking.
 * output: {
 * 	filename: '[name].js',
 * 	chunkFilename: 'js/[name].js',
 * 	publicPath: '/'
 * },
 */

	// Set advanced options
	.options({
		clearConsole: false,
		terser: {
			terserOptions: {
				compress: {},
				ecma: 8,
				ie8: false,
				mangle: true,
				module: false,
				nameCache: null,
				output: null,
				parse: {},
				safari10: false,
				toplevel: false,
				warnings: 'verbose'
			}
		}
	})


	// Set global variables for JavaScript.
	.autoload({
		'enquire.js': [
			'enquire', 'window.enquire'
		],
		femtojs: [
			'$', 'window.$'
		]
	})

	// Process CMS config files.
	.copy(`${Config.src.config}/cms`, Config.dist.config)

	// Process template files.
	.copy(Config.src.html, Config.dist.html)

	// Process asset files.
	.copy(Config.src.img, Config.dist.img)
	.copy(Config.src.audio, Config.dist.audio)
	.copy(Config.src.video, Config.dist.video)


	// Process JavaScript controller.
	.js(`${Config.src.js}/controller.js`, `${Config.dist.js}/${Config.slug}.js`)

	// Create source maps.
	.sourceMaps()


// Extract vendor files.
	.extract()


	// Check for Modernizr
	.then(() => {
		const mod = new Mod(`${Config.dist.js}/vendor/modernizr.min.js`, Config);
		if ((!mod.fileExists) || (mod.fileExists && mod.isStale)) {
			mod.build();
		}
	})
	.browserSync(new BS(Config));


/*
 *    Production only
 *--------------------------------------------------
 */
if (isProd) {
	mix.version();
}
