<?php
	function luvo_media_scripts() {
	    wp_enqueue_style( 'media_css' );
	}
	add_action( 'wp_enqueue_scripts', 'luvo_media_scripts' );
	
	get_template_part('parts/chrome/header');
?>
<div class="page-content central-column styled-text">
	<?php get_template_part('parts/snippets/nav-to-main'); ?>

	<div class="inner-column">
		<header class="page-header">
			<h1><?php post_type_archive_title(); ?></h1>
			<h2>The Luvo Guide to Spices and Seasonings</h2>
			<p>At Luvo, we like to say we&rsquo;re low in sodium but big on flavor. When we&rsquo;re experimenting with new recipes, we rely on herbs, spices and vinegars that amplify taste and add great color and texture to a meal without using a heavy hand on the salt shaker.</p>
			<p>Fresh herbs are fantastic for garnishes and they provide bold flavor accents. Their aromatic qualities work very well for roasting and sautéing, or for chopping and mixing into foods like mashed potatoes.</p>
			<p><strong>If you&rsquo;re looking to boost flavor in your cooking without using more salt, try some of these tips. Cooking is about creating, so feel free to experiment. Let your tastebuds be your guide.</strong></p>
		</header>
		<div class="pillars">
			<ul class="equalize">
				<li class="before sprite-before fresh">
					<h3>Start with fresh ingredients.</h3>
					<p>Buy fresh herbs and store them in the fridge in a plastic bag with a slightly damp paper towel wrapped around the stems. Parsley, cilantro and basil stay nice and fresh using this technique.</p>
				</li>
				<li class="before sprite-before dried">
					<h3>Dried herbs work best when infused in oil or water.</h3>
					<p>To season cooking liquid, crush the herbs with your fingers or saut&eacute; them a bit to wake them up. Crushing them with a mortar and pestle also works very well.</p>
				</li>
				<li class="before sprite-before versatile">
					<h3>Try fresh ginger, chiles and garlic.</h3>
					<p>These are versatile ingredients that can easily be used on a regular basis. Fresh grated ginger is widely used in Asian cuisines, and it adds a spicy zing to a variety of dishes. To use, first peel off the thin outer skin, then slice, mince or grate the ginger as called for by the recipe.</p>
				</li>
				<li class="before sprite-before heat">
					<h3>Don&rsquo;t be afraid to experiment with heat.</h3>
					<p>Dozens of culinary styles around the world turn to chile peppers for a huge diversity of tastes and effects. Popular pepper varieties include banana, poblano, jalapeño, serrano and cayenne. Pepper hotness can vary widely within a variety. For most recipes, hot peppers need to have their seeds and ribs.</p>
				</li>
			</ul>
		</div>
		<div class="spice-list">
			<div class="text">
				<h2>The Luvo Guide to Spices and Seasonings</h2>
				<p>These are some of the primary spices we use in our test kitchen. As with all dried herbs, seeds and spices, they should be stored in a cool dark place for no more than six months to maintain their best qualities.</p>
			</div>
			<ul>
				<?php query_posts($query_string . '&posts_per_page=100&orderby=menu_order&order=ASC'); if (have_posts()): while (have_posts()): the_post(); ?>
				<li>
					<figure>
						<div class="image">
							<div class="inner">
								<?php the_post_thumbnail('spice-sm'); ?>
							</div>
						</div>
						<figcaption>
							<h3><?php the_title(); ?></h3>
							<?php the_content(); ?>
						</figcaption>
					</figure>				
				</li>
				<?php endwhile; endif; ?>
			</ul>
		</div>
	</div><!--inner-column-->
</div><!-- page-content -->

<?php get_template_part('parts/chrome/footer'); ?>







