if (luvo === null || typeof(luvo) !== "object") { var luvo = new Object(); }

luvo.Calendar = (function() {
	var _instance;
	
	function kickoff() {
		return {
			/* Run initialization procedures
			* @param object options options that can be passed into the initialize method
			*/
			initialize: function(options) {
				var self = this;
				// attach event handlers
				jQuery(document).ready(function() {
					self.eventHandlers();
					
				});
			},
			/* Event handlers
			*/
			eventHandlers: function() {
				var self = this;
				self.set_variables();
				self.calendarThumbnailRotator();
				self.primaryCalendarRotator();
				self.loadingFunctions();
				self.filterCalendarTrigger();
				self.unfilterCalendarTrigger();
				self.eventHover();
				self.dateClick();
				self.dayAdvance();
				self.dayRegress();
				self.createAddToCalendar();
				self.addToCalendar();
			},
			set_variables: function(){
				calendar.optional_filters = Array( 'luvo-live-events', 'christine-day', 'samantha-cassetty', 'dr-mark-hyman' );
				window.downloadFile = function(sUrl) {
				    window.open(sUrl, '_self');
				}
				window.downloadFile.isSafari = navigator.userAgent.toLowerCase().indexOf('safari') > -1;
			},
			loadingFunctions: function(){
				var self = this;
				self.changeCalendarView( calendar.day_shown );
				self.updateAvailableEventDates();
				//check that there are still navigable dates before and after the current day
				self.disableDayNavigation();
			},
			calendarThumbnailRotator: function(){
				jQuery('.month-thumbs').flexslider({
					animation: "slide",
					controlNav: false,
					directionNav: false,
					animationLoop: false,
					slideshow: false,
					itemWidth: 210,
					itemMargin: 10,
					maxItems: 2,
					minItems: 2,
					move: 1,
					start: function(slider){
						slider.find('.slides li:not(.disabled)').on( 'click', function(){
							slide = jQuery(this).index() + 1;
							jQuery('.current-month').flexslider(slide);
						})
					}
				});
			},
			primaryCalendarRotator: function(){
				jQuery('.current-month').flexslider({
					animation: "slide",
					animationSpeed: 700,
					animationLoop: false,
					controlNav: false,
					directionNav: true,
					slideshow: false,
					smoothHeight: true,
					start: function(slider){
						jQuery('body').removeClass('loading');
						jQuery(slider.directionNav[0]).closest('.flex-direction-nav').append('<li class="prev-disabler"></li><li class="next-disabler"></li>');
					},
					before: function(slider){
						newSlide = slider.animatingTo;
						jQuery('.month-thumbs').flexslider(newSlide);
					}
				});
			},
			filterCalendarTrigger: function(){
				var self = this;

				jQuery('.events-calendar-panel .calendar-filters a').on('click', function(e){
					e.preventDefault();

					filter = jQuery(this).attr('data-filter');

					//Update array of active filters
					if ( calendar.active_filters.indexOf( filter ) > -1 ){
	        			index = calendar.active_filters.indexOf( filter );
						calendar.active_filters.splice( index, 1 );
					}else{
						calendar.active_filters.push( filter );
					}
					self.updateAvailableEventDates();
					self.updateQueryStringParameter( 'filters', filter, true );
					self.refreshActiveFilterClasses( filter );
					self.toggleUnfilter();

					//Check if the visible day has events that match the filter
					if( calendar.event_dates.indexOf( calendar.day_shown ) == -1 && calendar.active_filters.length > 0 ){
						
						//find the closest day that matches the filters starting with today
						if( calendar.event_dates.indexOf( calendar.today ) > -1 ){
							new_day = calendar.today;
						}else{
							new_day = self.findNextDay( calendar.today );
						}
						//if the returned day does not match the filter criteria look for a day in the past
						if( calendar.event_dates.indexOf( new_day ) < 0 ){ new_day = self.findPrevDay( calendar.today ) }
						self.loadNewDate( new_day );
					}

					//check that there are still navigable dates before and after the current day
					self.disableDayNavigation();

				})
			},
			updateAvailableEventDates: function(){

				new_event_dates = Array();

				if( calendar.active_filters.length > 0 ){

					//loop through dates in event_data
					jQuery.each( calendar.events_data, function( index, value ){
						check_date = index;

						//loop through events on date
						jQuery.each( calendar.events_data[check_date], function( index, value ){
							check_event = index;

							//loop through filters on event
							jQuery.each( calendar.events_data[check_date][check_event]['filters'], function( index, value ){
								if( calendar.active_filters.indexOf(value) >= 0 && new_event_dates.indexOf( check_date ) == -1 ){
									new_event_dates.push( check_date );
								}
							})
						})
					})
				}else{
					new_event_dates = Object.keys(calendar.events_data);
				}

				calendar.event_dates = Array();

				jQuery.each( new_event_dates, function( index, value ){
					calendar.event_dates.push( parseInt( value ) );
				} )

			},
			unfilterCalendarTrigger: function(){
				var self = this;

				jQuery('.clear-filters').on( 'click', function(e){
					e.preventDefault();

					calendar.active_filters = Array();
					history.pushState( null, null, '/events-calendar/');

					self.refreshActiveFilterClasses();
					self.updateAvailableEventDates();
					self.toggleUnfilter();
					self.disableDayNavigation();
				})
			},
			//Unapply and Reapply filter classes to filters and wrapper
			refreshActiveFilterClasses: function(){
				for ( var i=0; i < calendar.optional_filters.length; i++ ) {
					jQuery('.events-calendar-panel').removeClass( calendar.optional_filters[i] );
				}
				jQuery('.events-calendar-panel .calendar-filters a').removeClass('active');
				for ( var i=0; i < calendar.active_filters.length; i++ ) {
					jQuery('.events-calendar-panel').addClass( calendar.active_filters[i] );
					jQuery('.events-calendar-panel .calendar-filters [data-filter=' + calendar.active_filters[i] + ']' ).addClass('active');
				}
			},

			//Find a key in object
			// getItem: function( data, value_array, after ){
			// 	var self = this;
			// 	if( !after ){ after = 0; };
			// 	if ( data instanceof Object ) {
			//         for ( datetime in data ){
			//         	if( datetime > after ){
			//         		found = self.getSubMenuItem( data[datetime], value_array );
			//         		if ( found ) return datetime;
			//         	}
			//         }
			//     }
			// },
			// //Find a key in object in reverse
			// getItemReverse: function( data, value_array, before ){
			// 	var self = this;
				
			// 	if( !before ){ before = 9999999999; };

			// 	var reverse_array = Array();
			// 	for (var key in data ) {
			// 		if( parseInt(key) < before ){
			// 			reverse_array.push( key );
			// 		}
			// 	}

			// 	if ( data instanceof Object ) {
			//         jQuery.each( reverse_array, function( index, value ){
			//         	found = self.getSubMenuItem( data[value], value_array );
		 //        		if ( found ) return value;
			//         } );
			//     }
			// },
			// //Recuresively find key in object
			// getSubMenuItem: function ( data, value_array ) {
			// 	var self = this;
			// 	if ( data instanceof Object ) {
			//         for ( key in data ){
			//             if ( jQuery.inArray( data[key], value_array ) > -1 ){
			//                 return true;
			//             }else{
			//             	found = self.getSubMenuItem( data[key], value_array );
			//             	if ( found ) return found;
			//             }       
			//         }
			//     }
			// },

			//Open and close unfilter panel based on existence of filters
			toggleUnfilter: function(){
				//Check if any filters are active
				if( calendar.active_filters.length > 0 ){
					jQuery('.events-calendar-panel').addClass( 'filtered' );
					jQuery('.calendar-unfilter').css({
						'border-bottom': '1px solid #d3d3d3',
					}).stop().animate({
						'height': 52,
					}, 300);
				}else{
					jQuery('.events-calendar-panel').removeClass( 'filtered' );
					jQuery('.calendar-unfilter').stop().animate({
						'height': 0,
					}, 300, function(){
						jQuery(this).css({
							'border-bottom': 'none',
						})
					});
				}
			},
			updateQueryStringParameter: function( key, value, replace ) {
				url = window.location.href;
				split_url = url.split('?');

				//determine if there is already a query string
				if( split_url[1] ){
					query_string_object = jQuery.deparam( split_url[1] );

					//parse arrays in object
					for( var query_key in query_string_object ){
						if( query_string_object[query_key].split(',').length > 1 ){
							query_string_object[query_key] = query_string_object[query_key].split(',');
						}
					}
					//determine if key is already in use or if it is a calendar date
					if( query_string_object[key] && key != 'calendar'){

						//determine if index is an array
						if( query_string_object[key] instanceof Array ){

							filter_array = query_string_object[key];

							//determine if value is already in use
							if( jQuery.inArray( value, filter_array ) > -1 ){

								index = jQuery.inArray( value, filter_array );
								filter_array.splice( index, 1 );
								query_string_object[key] = filter_array;
							}else{
								filter_array.push( value );
								query_string_object[key] = filter_array;
							}

						}else{
							//determine if the value is already in use
							if( query_string_object[key] == value ){
								delete query_string_object[key];
							}else{
								query_string_object[key] = query_string_object[key] + ',' + value;
							}
						}

					}else{
						query_string_object[key] = value;
					}

					//if object still has filters
					if( Object.keys( query_string_object ).length > 0 ){

						//create query string
						new_string = '';
						for( var query_key in query_string_object ){

							if( query_string_object[query_key] instanceof Array ){
								query_string_object[query_key] = query_string_object[query_key].join();
							};
							new_string += '&' + query_key + '=' + query_string_object[query_key];
						}
						new_string = new_string.replace(/^\&/, '');
						new_url = split_url[0] + '?' + new_string;
					}else{
						new_url = split_url[0];
					}
					

				}else{
					new_url = split_url[0] + '?' + key + '=' + value;
				}
			    
			    if (replace == true){ history.pushState( null, null, new_url ); };
			    return new_url;
			},
			
			dateClick: function(){
				var self = this;

				//On date link click
				jQuery('.events-calendar-panel .current-month .slides li table a').on('click', function(e){
					e.preventDefault();

					//Determine the target date
					date = jQuery(this).attr('href').split('#');
					date = date[1];

					self.loadNewDate( date );
				})
			},

			//Add class to style the current day on the calendar view
			updateActiveCalendarDay: function( date ){
				target_class = '.day-' + date;
				jQuery('.events-calendar-panel .calendar-wrapper .current-month .slides li table .current-day-link').removeClass('current-day-link');
				jQuery( target_class + ' a').addClass('current-day-link');
			},

			//On right arrow click
			dayAdvance: function(){
				var self = this;

				jQuery('.events-calendar-panel .current-day .day-controls .next').on('click', function(e){
					e.preventDefault();
					if( !jQuery(this).hasClass('disabled') ){
						new_day = self.findNextDay();
						self.loadNewDate( new_day );
					}
				})
			},

			//Determine the next day that meets filter requirements
			findNextDay: function(){
				var self = this;

				today = calendar.day_shown;

				//check if there are events today
				if( calendar.event_dates.indexOf( today ) != -1 ){
					todays_index = calendar.event_dates.indexOf( today );
					next_index = todays_index + 1;
					if( next_index <= calendar.event_dates.length ){
						new_day = calendar.event_dates[ next_index ];
					};
				}else{
					//find the closest future date in array
					var closest = null;
					jQuery.each( calendar.event_dates, function( index, value ){
						if ( ( closest == null || Math.abs( value - today) < Math.abs(closest - today) ) && value > today ) {
							closest = value;
						}
					});
					new_day = closest;
				};

				if( typeof new_day == 'undefined' || new_day == null ){
					new_day = today;
				}

				return new_day;
			},

			//On left arrow click
			dayRegress: function(){
				var self = this;

				jQuery('.events-calendar-panel .current-day .day-controls .prev').on('click', function(e){
					e.preventDefault();

					if( !jQuery(this).hasClass('disabled') ){
						var day = self.findPrevDay();
						if( day ){
							self.loadNewDate( day );
						}
					}
				})
			},

			//Determine the previous day that meets filter requirements
			findPrevDay: function(){
				var self = this;

				today = calendar.day_shown;

				//check if there are events today
				if( calendar.event_dates.hasOwnProperty( today ) ){
					todays_index = calendar.event_dates.indexOf( today );
					prev_index = todays_index - 1;
					if( prev_index <= calendar.event_dates[0] ){
						new_day = calendar.event_dates[ prev_index ];
					};
				}else{
					//find the closest future date in array
					var closest = null;
					jQuery.each( calendar.event_dates, function( index, value ){
						if ( closest == null || Math.abs( value - today) < Math.abs(closest - today) && value < today ) {
							closest = value;
						}
					});
					new_day = closest;
				};

				if( typeof new_day == 'undefined'){
					new_day = today;
				}
				
				return new_day;
			},

			//Reload day view with new date
			loadNewDate: function( date ){
				var self = this;

				if( date != calendar.day_shown ){

					ajax_object = {
						'action':'query_event_posts',
						'query_date':date,
					};

					jQuery.post( ajaxurl, ajax_object, function( response ) {

						//fix height of current day panel
						set_height = jQuery('.current-day').height();
						jQuery('.current-day').height( set_height );

						//check if advancing or receeding
						if( date > calendar.day_shown ){
							jQuery('.current-day .frame').append( response );
							new_height = jQuery('.current-day .frame .slide:last-of-type').outerHeight();
							jQuery('.current-day .frame .slide:first-of-type').animate({
								'margin-left': '-50%',
							}, 1200, 'easeOutExpo', function(){
								jQuery(this).remove();
							});
						}else{
							jQuery('.current-day .frame').prepend(response);
							jQuery('.current-day .frame .slide:first-of-type')
								.css({
									'margin-left': '-50%',
								});
							new_height = jQuery('.current-day .frame .slide:first-of-type').outerHeight();
							jQuery('.current-day .frame .slide:first-of-type').animate({
								'margin-left': 0,
							}, 1200, 'easeOutExpo', function(){
								jQuery('.current-day .frame .slide:last-of-type').remove();
							});
						}
						//Adjust container height
						jQuery('.current-day').animate({
							'height': new_height,
						}, 1200, 'easeOutExpo', function(){
							jQuery(this).height('auto');
						});
						
						//Change indicators of new date
						calendar.day_shown = parseInt( date );
						self.updateQueryStringParameter( 'calendar', date, true );
						self.updateActiveCalendarDay( date );
						self.disableDayNavigation( date );
						self.changeCalendarView( date );
					});
				}
			},

			//Advance rotator to the month of the currently displayed day
			changeCalendarView: function( day ){

				var monthNames = [ 'january', 'february', 'march', 'april', 'may', 'june', 'july', 'august', 'september', 'october', 'november', 'december' ];

				day = parseInt( day );
				date = new Date( day * 1000 );
				month = date.getMonth();
				month = monthNames[month];
				index = jQuery( '#' + month ).index('.current-month .slides li');
				jQuery('.current-month').flexslider( index );
			},

			//Check if the date is the first or last available day and disable the relevant link
			disableDayNavigation: function(){

				//if target day is the earliest date, disable the back button
				last_index = calendar.event_dates.length - 1;

				if( calendar.event_dates[last_index] == calendar.day_shown ){
					jQuery('.events-calendar-panel .current-day .day-controls .next').addClass('disabled');
				//else enable it
				}else{
					jQuery('.events-calendar-panel .current-day .day-controls .next').removeClass('disabled');
				}

				//if target day is the earliest date, disable the back button
				if( calendar.event_dates[0] == calendar.day_shown ){
					jQuery('.events-calendar-panel .current-day .day-controls .prev').addClass('disabled');
				//else enable it
				}else{
					jQuery('.events-calendar-panel .current-day .day-controls .prev').removeClass('disabled');
				}
			},

			//reveal additional text and event toolbar
			eventHover: function(){
				jQuery( document ).on('mouseenter', '.events-calendar-panel .current-day .event', function(){
					element = jQuery(this);
					target = jQuery(this).find('.reveal');

					element.find('.ellipsis').hide();
					newHeight = target.find('.inner').outerHeight();
					
					target.stop().animate({
						'height': newHeight,
					}, 300);
					target.find('.inner').stop().delay(250).animate({
						'opacity': 1,
					}, 300);
				});
				jQuery( document ).on('mouseleave', '.events-calendar-panel .current-day .event', function(){
					element = jQuery(this);
					target = jQuery(this).find('.reveal');

					element.find('.ellipsis').show();
					target.stop().delay(250).animate({
						'height': 0,
					}, 300);
					target.find('.inner').stop().animate({
						'opacity': 0,
					}, 400);
				})
			},

			//use ics plugin to prepare downloadable calendar files for each event
			createAddToCalendar: function(){
				var self = this;

				calendar.events = new Object();
				jQuery.each( calendar.events_data, function( index, value ){
					jQuery.each( value, function( index, event_entry ){

						calendar.events[ event_entry.id ] = ics();
						calendar.events[ event_entry.id ].addEvent(	event_entry.title, 
											event_entry.description, 
											event_entry.location, 
											event_entry.start_time, 
											event_entry.end_time);

						//Add data to be used for file creation in safari
						calendar.events[ event_entry.id ]['title'] = event_entry.title;
						calendar.events[ event_entry.id ]['description'] = event_entry.description;
						calendar.events[ event_entry.id ]['location'] = event_entry.location;
						calendar.events[ event_entry.id ]['start_time'] = event_entry.start_time_ics;
						calendar.events[ event_entry.id ]['end_time'] = event_entry.end_time_ics;
					} )
				})
			},

			//On add to calendar click
			addToCalendar: function(){
				var self = this;
				jQuery( document ).on('click', '.events-calendar-panel .current-day .event .tools .calendar', function(e){
					e.preventDefault();
					event_id = jQuery(this).attr('data-event-id');

			    	if ( typeof window.downloadFile.isSafari != 'undefined' ) {
			    		self.create_ICS_file( event_id );
					}else{
						event_id = jQuery(this).attr('data-event-id');
						calendar.events[ event_id ].download();
					}
				})
			},

			create_ICS_file: function( event_id ){
				var self = this;
				//$id, $description, $start_time, $end_time, $location, $title

				object = {};
				object['action'] 		= 'create_ICS_file';
				object['id'] 			= event_id;
				object['description'] 	= calendar.events[ event_id ]['description'];
				object['start_time'] 	= calendar.events[ event_id ]['start_time'];
				object['end_time'] 		= calendar.events[ event_id ]['end_time'];
				object['location'] 		= calendar.events[ event_id ]['location'];
				object['title'] 		= calendar.events[ event_id ]['title'];

				sUrl = 

				jQuery.post( ajaxurl, object, function(response) {
					self.safari_download_ICS( response );
				});
			},

			safari_download_ICS: function(sUrl) {

		        //Creating new link node.
		        var link = document.createElement('a');
		        link.href = sUrl;
		 
		        if ( link.download !== undefined ){
		            //Set HTML5 download attribute. This will prevent file from opening if supported.
		            var fileName = sUrl.substring(sUrl.lastIndexOf('/') + 1, sUrl.length);
		            link.download = fileName;
		        }
		 
		        //Dispatching click event.
		        if (document.createEvent) {
		            var e = document.createEvent('MouseEvents');
		            e.initEvent('click' ,true ,true);
		            link.dispatchEvent(e);
		            return true;
		        }
			 
			    // Force file download (whether supported by server).
			    var query = '?download';
			 
			    window.open(sUrl + query);
			}
			
		};
	};
	return {
	/* Get an instance of this singleton
	* @return object
	*/
		getInstance: function() {
			if (!_instance)
			_instance = kickoff();
			return _instance;
		}
	};
})();

// Instantiate the class
luvoCalendar = luvo.Calendar.getInstance();
// Run initialize method
luvoCalendar.initialize();














