if (luvo === null || typeof(luvo) !== "object") { var luvo = new Object(); }

luvo.recipes = (function() {
	var _instance;
	
	function kickoff() {
		return {
			/* Run initialization procedures
			* @param object options options that can be passed into the initialize method
			*/
			initialize: function(options) {
				var self = this;
				// attach event handlers
				jQuery(document).ready(function() {
					self.eventHandlers();
				});
			},
			/* Event handlers
			*/
			eventHandlers: function() {
				var self = this;
				self.grid();
				self.resize_functions();

				self.validate();
				self.update_submit_button();

				self.cta_click();
				self.recipe_intent_toggle_hover();
				self.recipe_intent_toggle_click();
				self.close_modal();
				self.close_success_modal();
				self.filter_grid();
				self.hash_filter();
				self.unfilter_grid();
				self.form_submit();
			},
			resize_functions: function(){
				var self = this;
				jQuery(window).on('resize', self.debounce( self.check_isotope, 200 ) );
			},
			check_isotope: function() {
				var self = this;

				if ( jQuery(window).width() > 300 && !self.isIsotopeInit ) {
					// init isotope if widescreen
					jQuery('.healthy-recipes-index .grid').imagesLoaded( function() {
						jQuery('.healthy-recipes-index .grid').isotope({
							itemSelector: '.tile',
							layoutMode: 'packery',
							stamp: '.cta-tile',
						})
						self.isIsotopeInit = true;
					});
				} else if ( jQuery(window).width() <= 300 && self.isIsotopeInit ) {
					// disable isotope if default and already intialized
					jQuery('.healthy-recipes-index .grid').isotope('destroy');
					self.isIsotopeInit = false;
				}
			},  
			debounce: function ( fn, threshold ) {
				var self = this;
				var timeout;
				return function debounced() {
					if ( timeout ) {
						clearTimeout( timeout );
					}
					function delayed() {
						fn();
						timeout = null;
					}
					setTimeout( delayed, threshold || 100 );
				}
			},
			grid: function(){
				var self = this;

				self.isotope_container = jQuery('.healthy-recipes-index .grid');
				self.isIsotopeInit = false;
				  
				self.check_isotope();
			},
			validate: function(){

				jQuery.validator.addMethod('block_links', function(value, element, param) {
					var re_weburl = new RegExp( '(https?:\/\/[^ ]+)', 'gi');
					count = ( value.match(re_weburl) || [] ).length;
					return this.optional(element) || (count<1) ; 
				}, "Linking is not supported");

				jQuery(".recipe-form").validate({
					rules: {
						'recipe_ingredients': {
							required: true,
							block_links: true,
							minlength: 100
						},
						'recipe_instructions': {
							required: true,
							block_links: true,
							minlength: 100
						},
						'recipe_notes': {
							block_links: true
						},
						'recipe_conditions': {
							required: true,
						}
					},
					errorPlacement: function(error, element) {
						if ( element.attr('name') == 'recipe_conditions' ) {
							error.insertAfter('.disclaimer');
						} else {
							error.insertAfter(element);
						}
					}
				});
			},
			update_submit_button: function(){
				jQuery('.recipe-form input, .recipe-form textarea').on('change', function(){
					if( jQuery('.recipe-form').valid() ){
						jQuery('.recipe-form').find('.submit').removeClass('disabled');
					}else{
						jQuery('.recipe-form').find('.submit').addClass('disabled');
					}
				})
			},
			cta_click: function(){
				var self = this;
				jQuery('.healthy-recipes-index .grid .cta-tile').on('click', function(e){
					e.preventDefault();
					jQuery('.healthy-recipes-index .recipe-list').addClass('modal-open');
					jQuery('.healthy-recipes-index .recipe-form-modal').fadeIn();
					new_height = jQuery('.recipe-form').outerHeight() + 100;
					jQuery('.grid-wrapper').css({
						'min-height': new_height,
					})
				})
			},
			close_modal: function(){
				jQuery('.healthy-recipes-index .modal-background, .healthy-recipes-index .close-icon').on('click', function(e){
					e.preventDefault();
					jQuery(this).closest('.modal').fadeOut(700, function(){
						jQuery('.healthy-recipes-index .recipe-list').removeClass('modal-open');
						jQuery('.grid-wrapper').css({
							'min-height': 0,
						})
					});
				})
			},
			close_success_modal: function(){
				jQuery('.healthy-recipes-index').on('click', function(e){
					if(jQuery('.recipe-success-modal').hasClass('active')){
						jQuery('.recipe-success-modal').fadeOut(700, function(){
							jQuery(this).removeClass('active');
						})
					}
				})
			},
			recipe_intent_toggle_hover: function(){
				var self = this;
				jQuery('.recipe-intent-toggle').on('mouseenter', function(){
					jQuery(this).closest('.recipe-intent-filter').addClass('active');
				})
				jQuery('.recipe-intent-filter').on('mouseleave', function(){
					jQuery(this).removeClass('active');
				})
			},
			recipe_intent_toggle_click: function(){
				var self = this;
				jQuery('.recipe-intent-toggle').on('click', function(e){
					e.preventDefault();
					if( jQuery(this).closest('.recipe-intent-filter').hasClass('active') ){
						jQuery(this).closest('.recipe-intent-filter').removeClass('active');
					}else{
						jQuery(this).closest('.recipe-intent-filter').addClass('active');
					}
				})
			},
			filter_grid: function(){
				var self = this;
				jQuery('.recipe-intents a').on('click', function(e){
					e.preventDefault();
					if( jQuery(this).hasClass('active')){
						jQuery('.recipe-list').removeClass('filtered');
						self.isotope_container.isotope({ 
							filter: '*',
						});
						jQuery(this).removeClass('active');
					}else{
						jQuery('.recipe-list').addClass('filtered');
						jQuery('.recipe-intent-filter a').removeClass('active');
						new_filter = jQuery(this).attr('data-filter');
						self.isotope_container.isotope({ 
							filter: '.tile-' + new_filter,
						});
						jQuery(this).addClass('active');
					}
					jQuery('.recipe-intent-filter').removeClass('active');
				})
			},
			hash_filter: function(){
				var self = this;

				new_filter_slug = window.location.hash;
				if( new_filter_slug != '') new_filter_slug = new_filter_slug.split('#')[1];
				new_filter = '.tile-' + new_filter_slug;
				new_filter_name = new_filter_slug.replace('-', ' ');;
				if( jQuery(new_filter).length > 0 ){
					self.isotope_container.isotope({ 
						filter: new_filter,
					});
					jQuery('.recipe-intent-filter').hide();
					jQuery('.recipe-tag-filter').show().append(
						'<a class="remove-tag-filter" href="#remove-filter-' + new_filter_slug + '">Results for <span>' + new_filter_name + '</span></a>'
					)
				}
			},
			unfilter_grid: function(){
				var self = this;
				jQuery('.remove-tag-filter').on('click', function(e){
					e.preventDefault();
					self.isotope_container.isotope({ 
						filter: '*',
					});
					jQuery('.recipe-intent-filter').show();
					jQuery('.recipe-tag-filter').hide();
					if(history.pushState) {
						history.pushState(null, null, window.location.pathname);
					}
				})
			},
			form_submit: function(){
				jQuery(".recipe-form").submit(function (e) {
					var form = this;
					e.preventDefault();
					if( !jQuery(form).valid() ) return;
					ga('send', 'event', 'button', 'form_submit', 'recipe');
					 window._tfa = window._tfa || [];
 					_tfa.push({notify:"action", name: 'recipe'});
					luvoMain.outbrain_tracking_pixel();

					setTimeout( function () {
						form.submit();
					}, 500);
				});
			}


		};
	};
	return {
	/* Get an instance of this singleton
	* @return object
	*/
		getInstance: function() {
			if (!_instance)
			_instance = kickoff();
			return _instance;
		}
	};
})();

// Instantiate the class
luvo_recipes = luvo.recipes.getInstance();
// Run initialize method
luvo_recipes.initialize();










