if (luvo === null || typeof(luvo) !== "object") { var luvo = new Object(); }

luvo.luv_notes = (function() {
	var _instance;
	
	function kickoff() {
		return {
			/* Run initialization procedures
			* @param object options options that can be passed into the initialize method
			*/
			initialize: function(options) {
				var self = this;
				// attach event handlers
				jQuery(document).ready(function() {
					self.eventHandlers();
				});
			},
			/* Event handlers
			*/
			eventHandlers: function() {
				var self = this;
				self.grid();
				self.resize_functions();

				self.validate();
				self.file_input_change();

				self.cta_click();
				self.close_modal();
				self.close_success_modal();
				self.form_submit();
			},
			resize_functions: function(){
				var self = this;
				jQuery(window).on('resize', self.debounce( self.check_packery, 200 ) );
			},
			check_packery: function() {
				var self = this;

				if ( jQuery(window).width() > 982 && !self.isPackeryInit ) {
					// init packery if widescreen
					jQuery('.luv-notes .grid').packery({
						itemSelector: '.tile',
					});
					self.isPackeryInit = true;
				} else if ( jQuery(window).width() <= 982 && self.isPackeryInit ) {
					// disable packery if default and already intialized
					jQuery('.luv-notes .grid').packery('destroy');
					self.isPackeryInit = false;
				}
			},  
			debounce: function ( fn, threshold ) {
				var self = this;
				var timeout;
				return function debounced() {
					if ( timeout ) {
						clearTimeout( timeout );
					}
					function delayed() {
						fn();
						timeout = null;
					}
					setTimeout( delayed, threshold || 100 );
				}
			},
			grid: function(){
				var self = this;

				self.packery_container = jQuery('.luv-notes .grid');
				self.isPackeryInit = false;
				  
				self.check_packery();
			},
			validate: function(){

				jQuery.validator.addMethod('filesize', function(value, element, param) {
					return this.optional(element) || (element.files[0].size <= param) 
				});

				jQuery(".luv-note-form").validate({
					rules: {
						'luv_note': {
							required: true,
							minlength: 100
						},
						'luv_conditions': {
							required: true,
						},
						'user_avatar':{
							extension: true,
							filesize: 5148576,
						}
					},
					messages: {
						'user_avatar': {
							extension: "File must be jpg, png, or gif.",
							filesize: "File must be less than 5MB.",
						},
					},
					errorPlacement: function(error, element) {
						if ( element.attr('name') == 'luv_conditions' ) {
							error.insertAfter('.disclaimer');
						} else {
							error.insertAfter(element);
						}
					}
				});
			},
			file_input_change: function(){
				jQuery(".luv-note-form input[type=file]").on( 'change', function(){
					file_name = jQuery(this).val().split('\\').pop();
					jQuery(this).closest('.file-wrapper').find('.file-name').html( file_name );
				})
			},
			cta_click: function(){
				var self = this;
				jQuery('.luv-notes .grid .cta-tile').on('click', function(e){
					e.preventDefault();
					self.open_modal();
				})
			},
			open_modal: function(){
				jQuery('.luv-notes .form-modal-wrapper').fadeIn();
			},
			close_modal: function(){
				jQuery('.luv-notes .modal-background, .luv-notes .close-icon').on('click', function(e){
					e.preventDefault();
					jQuery(this).closest('.modal-wrapper').fadeOut(1000);
				})
			},
			close_success_modal: function(){
				jQuery('.page-luv-notes').on('click', function(e){
					if(jQuery('.success-modal-wrapper').hasClass('active')){
						jQuery('.luv-notes .success-modal-wrapper').fadeOut(1000, function(){
							jQuery(this).removeClass('active');
						})
					}
				})
			},
			form_submit: function(){
				jQuery('.luv-note-form').submit(function (e) {
					var form = this;
					e.preventDefault();
					if( !jQuery(form).valid() ) return;
					ga('send', 'event', 'button', 'form_submit', 'luv_note');
					luvoMain.outbrain_tracking_pixel();

					setTimeout( function () {
						form.submit();
					}, 500);
				});
			}

		};
	};
	return {
	/* Get an instance of this singleton
	* @return object
	*/
		getInstance: function() {
			if (!_instance)
			_instance = kickoff();
			return _instance;
		}
	};
})();

// Instantiate the class
luvo_luv_notes = luvo.luv_notes.getInstance();
// Run initialize method
luvo_luv_notes.initialize();















