<?php
	function luvo_calendar_scripts() {
		wp_enqueue_style( 'flexslider_css' );
	    wp_enqueue_style( 'calendar-css' );
	    wp_enqueue_script('filesaver');
	    wp_enqueue_script('blob');
	    wp_enqueue_script('ics');
	    wp_enqueue_script('bbq');
	    wp_enqueue_script('resize');
		wp_enqueue_script('flexslider_js');
	    wp_enqueue_script('calendar');
	}
	add_action( 'wp_enqueue_scripts', 'luvo_calendar_scripts' );
	
	get_template_part('parts/chrome/header');
?>
<?php 

	$query_string = $_SERVER['QUERY_STRING'];
	parse_str($query_string, $query_array);


	$dt = new DateTime();
	$dt->setTimeZone(new DateTimeZone('America/New_York'));
	$timestamp = $dt->format('U') + $dt->getOffset();
	$timestamp = strtotime("00:00:00", $timestamp);

	$current_month = date( 'n', $timestamp );
	$query_date = ( isset( $query_array['calendar'] ) )? $query_array['calendar']: $timestamp; //check if there is a query string
	$query_date_start = strtotime("00:00:00", $query_date);

	$query_filter_array = isset( $query_array['filters'] )? explode( ',', $query_array['filters'] ): array();

	$events_data = array();
	$args = array( 
		'order' => 'ASC',
		'orderby' => 'meta_value', 
		'meta_key' => 'wpcf-event-date',
		'post_type' => 'events', 
		'post_count' => 999,
		'posts_per_page' => 100,
		'meta_query' => array(
			array(
				'key'     => 'wpcf-event-date',
				'value'   => array( $timestamp, 9999999999 ),
				'type'    => 'numeric',
				'compare' => 'BETWEEN',
			),
		),
	);

	$the_query = new WP_Query( $args ); 
	if ( $the_query->have_posts() ): while ( $the_query->have_posts() ): $the_query->the_post();
		$event_time = get_post_meta($post->ID, 'wpcf-event-date', true );
		$event_day = strtotime('0:00', $event_time);
		$event_title = get_the_title();
		$event_duration = get_post_meta($post->ID, 'wpcf-event-duration', true );
		
		$event_description = get_the_content();
		$event_location = get_post_meta($post->ID, 'wpcf-event-location', true );

		//Filters
		$filters = array();
		$event_filters = get_the_terms( $post->ID, 'event-filters' ); 
		foreach($event_filters as $event_filter){
			$filters[] = $event_filter->slug;
		};
		
		//Types
		$types = array();
		$event_types = get_the_terms( $post->ID, 'event-types' ); 
		foreach($event_types as $event_type){
			$types[] = $event_type->slug;
		};

		$event_details = array(
			'id' 			=> 	$post->ID,
			'title' 		=> 	$event_title,
			'description' 	=>	$event_description,
			'location'		=>  $event_location,
			'type' 			=>	$types,
			'filters' 		=> 	$filters,
			'start_time' 	=>	date( 'n/j/Y g:i a', intval( $event_time ) ),
			'start_time_ics'=> 	date( 'Ymd\THis', intval( $event_time ) ),
			'end_time' 		=>	date( 'n/j/Y g:i a', intval( $event_time ) + floatval( $event_duration ) * 3600 ),
			'end_time_ics' 	=>	date( 'Ymd\THis', intval( $event_time ) + floatval( $event_duration ) * 3600 ),
		);
		$events_data[$event_day][] = $event_details;
	endwhile; endif; wp_reset_query();

	//print_r($events_data);
?>

<script type="text/javascript">
	if ( calendar === null || typeof(calendar) !== "object" ) { var calendar = {}; }
	calendar.events_data = <?php echo json_encode($events_data); ?>;
	calendar.active_filters = <?php echo json_encode( $query_filter_array ); ?>;
	calendar.today = <?php echo $timestamp; ?>;
	calendar.day_shown = <?php echo $query_date_start; ?>;
	calendar.event_dates = <?php echo json_encode( array_keys($events_data) ); ?>;
</script>

<?php if (have_posts()): ?>

<div class="page-content central-column">
	<?php get_template_part('parts/snippets/nav-to-main'); ?>

<div class="inner-column events-calendar-panel clearfix  <?php if( isset( $query_array['filters'] ) ){ echo 'filtered '. str_replace(',', ' ', $query_array['filters'] ); }; ?>" data-calendar="<?php echo $query_date; ?>">
	<header class="page-header styled-text">
		<h1>Events Calendar</h1>
		<?php the_content() ?>
	</header>

	<div class="calendar-filters clearfix">
		<a href="#" data-filter="luvo-live-events" <?php if( in_array('luvo-live-events', $query_filter_array ) ){ echo 'class="active"'; } ?> >
			<div class="image">
				<img class="standard" src="<?php echo get_template_directory_uri(); ?>/assets/img/events-calendar/events-filter-luvo-live-events.jpg" />
			</div>
			<p>Luvo Live Events</p>
		</a>
		<a href="#" data-filter="christine-day" <?php if( in_array('christine-day', $query_filter_array ) ){ echo 'class="active"'; } ?>>
			<div class="image">
				<img class="standard" src="<?php echo get_template_directory_uri(); ?>/assets/img/events-calendar/events-filter-christine-day.jpg" />
			</div>
			<p>Christine Day</p>
		</a>
		<a href="#" data-filter="samantha-cassetty" <?php if( in_array('samantha-cassetty', $query_filter_array ) ){ echo 'class="active"'; } ?>>
			<div class="image">
				<img class="standard" src="<?php echo get_template_directory_uri(); ?>/assets/img/events-calendar/events-filter-samantha-cassetty.jpg" />
			</div>
			<p>Samantha Cassetty</p>
		</a>
		<a href="#" data-filter="dr-mark-hyman" <?php if( in_array('dr-mark-hyman', $query_filter_array ) ){ echo 'class="active"'; } ?>>
			<div class="image">
				<img class="standard" src="<?php echo get_template_directory_uri(); ?>/assets/img/events-calendar/events-filter-dr-mark-hyman.jpg" />
			</div>
			<p>Dr. Mark Hyman</p>
		</a>
	</div>
	<div class="calendar-unfilter clearfix <?php if( count($query_filter_array) > 0 ){ echo 'open';} ?>">
		<a href="#" class="clear-filters">Clear all Filters</a>
	</div>

	<div class="calendar-wrapper">
		<div class="current-month">
			<?php //create 12 month slides from $timestamp ?>
			<ul class="slides">
<?php for( $i=0; $i < 12 ; $i++ ){ ?>
<?php include('parts/singles/calendar.php'); ?>
<?php } //for months ?>
			</ul>
		</div>
		<div class="month-thumbs">
			<?php //create 6 month thumbnails + 2 dead links from $real_date ?>
			<ul class="slides">
<?php for( $i=0; $i < 14 ; $i++ ){ ?>
<?php include('parts/singles/calendar-thumbnail.php'); ?>
<?php } //for months ?>
			</ul>
		</div>
	</div><!-- Calendar Wrapper -->

<?php 
	reset( $events_data );
	$first_key = key( $events_data );
	$event_dates = array_keys( $events_data );
	$last_key = count( $event_dates ) - 1;
	$last_key = $event_dates[ $last_key ];
?>
	<div class="current-day">
		<nav class="day-controls">
			<ul>
				<li>
					<a href="#" class="prev <?php if( $first_key == $query_date ){ echo 'disabled'; } ?>"><span class="offscreen">Previous</span></a>
				</li>
				<li>
					<a href="#" class="next <?php if( $last_key == $query_date ){ echo 'disabled'; } ?>"><span class="offscreen">Next</span></a>
				</li>
			</ul>
		</nav>
		<div class="frame clearfix">
<?php include('parts/singles/day.php'); ?>	
		</div><!--Frame-->
	</div> <!-- Current Day -->

	</div>
</div>

<?php endif; ?>



<?php get_template_part('parts/chrome/footer'); ?>








