# StayAlfred.com
---
## Table of Contents
1. About this repository
    1. Server environment
    1. Directory tree
    1. Code-level task tracking
1. Technical requirements
    1. Node.js
	  1. Bower
		1. Gulp.js
1. Getting started
1. Tasks
1. Team contact information

---
# About this project
The StayAlfred.com repository is run with [Git Source Control Management](https://git-scm.com/).


## Server environment

* ###### Server engine
  * _Software_: Apache2
  * _Version_: 20051115
  * _Ports_: 80 (_http_), 443 (_https_)

* ###### Server language
  * _Software_: PHP
  * _Version_: 7.0.20

* ###### Database
  * _Software_: MySQL
  * _Version_: 5.6.35
  * _Ports_: 3306 (_http_)

* ###### phpMyAdmin
  * _Version_: 4.7.3


## Directory tree
--
###### Key
* **Root item**
* _Directory_
* `filename.extension`

--
* **___gulp_** - contains the _Gulp.js_ task runner configuration files and individual tasks.
    * _config_
      * _methods_—commonly used methods for DRY code.
      * _settings_—settings for larger module packages.
      * `config.js`—loads all methods, settings, paths, and other common variables. Is used by all Gulp tasks.
    * _tasks_—all of the individual Gulp tasks.
* **_bower_components_**—all Bower dependencies and vendor files. Will only appear after full installation.
* **_dist_**—the compiled website. If using MAMP or a similar local hosting environment, point the web root here.
* **_node_modules_**—all Node.js dependencies and vendor files. Will only appear after full installation.
* **src**—all of the source files. Edit files here and then compile them. Editing theme files in the **_dist_** directory is one way to ensure that your changes will be lost.
    * _media_—site images, audio, and media files.
    * _scripts_—theme JavaScript.
    * _styles_—theme styles (via Sass) and font files.
    * _templates_—theme template files, including controllers like `functions.php`
* **`.gitignore`**—a manifest of files that Git should not include in the repository. If something won't commit to the repository, it's probably because of something in this file.
* **`.jshintrc`**—a lint configuration file (JavaScript).
* **`.scss-lint.yml`**—a lint configuration file (Sass).
* **`bower.json`**—a manifest of vendor files required by the site. Used by Bower to fetch dependencies during installation.
* **`gulpfile.js`**—the main task runner file that contains all of the task definitions.
* **`package.json`**—a "living", "breathing" document about the website. Contains all the information the computer needs for installation.
* **`README.md`**—this very file! How meta.

## Code-level task tracking

All files in this repository are subject to a comment-based, inline tracking system. Doing a search for the following tags will reveal notes made by developers:

* `TODO`—general, non-breaking to-do.
* `FIXME`—needs to be fixed; breaking bug.
* `CHANGED`—when a quick change is made to a major piece of code; often should be included with `HACK`, `REVIEW`, and `IDEA`.
* `IDEA`—thoughts on improving code or processes.
* `HACK`—a temporary fix that works, but needs to be better implemented.
* `NOTE`—general notes.
* `REVIEW`—request for review.
* `BUG`—reporting a bug that needs fixing.
* `QUESTION`—general questions.

---
# Technical requirements

While it's fine to install these on your own, to avoid the possibility of permissions issues, I would suggest using a package manager like [Homebrew](https://brew.sh/).

1. [Node.js](https://nodejs.org/en/)
    * [Installation](https://nodejs.org/en/download/)
    * Installation (Homebrew): `brew install node; brew install npm`
    * [Documentation](https://nodejs.org/en/docs/)
1. [Gulp.js](https://gulpjs.com/)
    * Dependent on `Node.js`
    * Installation (Node): `npm i -g gulp`
    * Installation (Homebrew): `brew install gulp`
    * [Documentation](https://github.com/gulpjs/gulp)
1. [Bower](https://bower.io/)
    * Dependent on `Node.js`
    * Installation (Node): `npm i -g bower`
    * Installation (Homebrew): `brew install bower`
    * [Documentation](https://bower.io/#getting-started)
---
# Getting started

1. Ensure that you have the technical requirements installed before proceeding.
    * `which node`
    * `which npm`
    * `which gulp`
    * `which bower`
1. Create a new directory to house the repository.
1. Clone the Git repository into your newly created folder.
    * _Using the Terminal_: `$ git clone https://nick-snyder.git.beanstalkapp.com/alf_stayalfred.git`
    * _Using a GUI_:
        1. Find and click `Clone remote repository` or similar.
        1. Set mode to `HTTPS`.
        1. Enter this URL: `https://nick-snyder.git.beanstalkapp.com/alf_stayalfred.git`
        1. Choose your newly created folder as a destination.
        1. Click `Clone` or similar.
1. Once cloned, open the directory in a Terminal.
    * `cd your/directory/path/here`
1. Type and return: `npm install`.
    * This will install the neccesary packages for Node.js first and then will install Bower packages after.
1. Using a text editor, open `__gulp/config/config.js`
1. Update the `env` variable to reflect your environment.
1. Using the Terminal, type and return: `gulp updateDatabaseEnvironment`
1. Install the database located at: `src/backups/`
    * **Database name**: `wp_alfredbizcor`
1. Using a text editor, open `dist/wp-config-sample.php`.
1. Edit the following to reflect your local environment
    * `DB_USER`
    * `DB_USER`
    * `DB_PASSWORD`
    * **NOTE**: Due to variation and security concerns, `wp-config.php` is **not** tracked by Git.
1. Save `dist/wp-config-sample.php` as `dist/wp-config.php`.

---
# Tasks

A list of executable Gulp tasks. To run any of these:
1. Go to the project directory in a Terminal window.
1. Type and return `gulp [Task Name]`.
    * For the case of `default`, you can simply type `gulp`.

## Controller Tasks
* #### `default`
    * Alias for `start`.
* #### `build`
    * Your primary task. Processes templates, styles, scripts, fonts, and media.
* #### `start`
    * Runs all the tasks as `build`, but automatically opens project in browser.
* #### `rebuild`
    * Deletes all processed theme files, then builds everything from scratch. Good for when structural changes happen.

### Sub Tasks
* #### `cleanThemeFiles`
    * Deletes all processed theme files.
* #### `deploySiteFiles`
    * Deploys new/changed files to staging server.
    * **NOTE**: only Nick Snyder (<nick@nicksnyder.is>) has the ability to run this, as it's his staging server.
* #### `processImages`
    * Moves and minifies images.
* #### `processStyles`
    * Compiles and processes CSS>
* #### `processTemplates`
    * Compiles and moves PHP files.
* #### `processWebFonts`
    * Creates, processes, and converts web font files.
* #### `syncDatabase`
    * Syncs the staging server database with the local environment.
    * **NOTE**: only Nick Snyder (<nick@nicksnyder.is>) has the ability to run this, as it's his staging server.
* #### `updateDatabaseEnvironment`
    * Updates the database backup to reflect the server environment in `__gulp/config/config.js`.
* #### `watch`
    * Watches files for local changes. When a file is changed, the appropriate processing task will automatically run. For example, a change detected in a `.scss` file will trigger `processStyles`.
    * This task also watches the `dist` directory for changes and will automatically load/reload changes into your browser.
---

## Team contact information

* ##### Roth Fouty (_Director of Software_)
    * <roth.fouty@stayalfred.com>

* ##### Adam Chronister (_Director of Digital Marketing_)
    * <adam.chronister@stayalfred.com>

* ##### Mark Simonds (_Developer_)
    * <mark.simonds@stayalfred.com>

* ##### Jeanne Ryan (_Person Who Does Not Have a Job Title in Her Email Signature or on the Website_)
    * <jeanne.ryan@stayalfred.com>

* ##### Lindsay Suda (_Social Media Strategist_)
    * <lindsay.suda@stayalfred.com>

* ##### Nick Snyder (_Contract Developer_)
    * <nick@nicksnyder.is>
