<?php

add_filter( 'body_class', function( $classes = array() ){
	global $post;

	$custom_pages = array( 'listings', 'listing_detail', 'checkout', 'thank_you', 'custom_quote' );
	$custom_page_ids = array();
	foreach( $custom_pages as $page ){
		$page_id = get_option( 'resortpro_'.$page.'_page_id', null );
		if( !is_null( $page_id ) )
			$custom_page_ids[ $page_id ] = $page;
	}

	if( array_key_exists ( $post->ID, $custom_page_ids ) ){
		$classes[] = 'streamline-page-' . $custom_page_ids[ $post->ID ];
	}

	return $classes;

});


add_filter( 'streamlinecore_sales_number', 'streamlinecore_phone' );
function streamlinecore_phone( $phone ){

	if( class_exists( 'StreamlineCore_Settings' ) ){
		$phone = StreamlineCore_Settings::get_options( 'phone' );
		if( !empty( $phone ) ) return $phone;
	} else {
		$streamlinecore_settings = get_option( 'pmt_plugin_resortpro', '' );
		if ( is_array( $streamlinecore_settings ) && isset( $streamlinecore_settings['phone'] ) ){
			return $streamlinecore_settings['phone'];
		}
    }

    return $phone;
}

add_action( 'stayalfred-cities', 'stayalfred_cities', 10, 1 );
function stayalfred_cities( $cities ) {
  $page_arr = stayalfred_get_cities();

  if ( ! sizeof( $page_arr ) )
    return;

  $odd = count($page_arr) % 2;
?>
<div class="block">
  <div class="container">
    <div class="row">
      <?php for ( $i = 0; $i < sizeof( $page_arr ); $i++ ) : ?>
        <?php
          // default
          $image_url = NULL;

          // get featured image url
          $post_thumbnail_id = get_post_thumbnail_id( $page_arr[$i]->ID );
          if ( $post_thumbnail_id ) {
            $image_src = wp_get_attachment_image_src( $post_thumbnail_id, 'featured-image-city' );
            if ( is_array( $image_src ) ) {
              $image_url = $image_src[0];
            }
          }

          // get starting price
          $starting_price = (int)get_post_meta( $page_arr[$i]->ID, 'streamline_city_starting_price', TRUE );

          // figure out group
			 $group = 1;
			 $per_row = 'col-sm-4';
//			 if( $odd && $i > ( sizeof($page_arr) - 4 ) ) $per_row = 'col-sm-4';
        ?>

        <div class="<?php echo $per_row; ?> city-group-<?php echo $group ?>" >
          <a href="<?php echo get_search_by_area_id_url( $page_arr[$i]->ID ) ?>" class="link-block">
            <div class="dummy"></div>
            <div class="element"<?php if ( ! is_null( $image_url ) ) : ?> style="background-image: url('<?php echo $image_url ?>');"<?php endif; ?>>
              <h4 class="bottom">
                <span>
                  <?php _e( 'Downtown', 'stayalfred-theme' ) ?> <?php echo $page_arr[$i]->post_title ?>
                  <?php if ( $starting_price > 0 ) : ?>
                    <br><span><?php _e( 'from', 'stayalfred-theme' ) ?> $<?php echo $starting_price ?></span>
                  <?php endif; ?>
                </span>
              </h4>
            </div>
          </a>
        </div>

      <?php endfor; ?>

      <div class="row"<?php if ( sizeof( $page_arr ) <= $cities ) : ?> style="display: none"<?php endif; ?>>
        <div class="col-md-8 col-md-offset-2 center">
          <a href="javascript:void(0);" class="btn btn-default btn-lg btn-cities-more" data-current-group="1" data-total-groups="<?php echo $group ?>"><?php _e( 'Show more destinations', 'stayalfred-theme' ) ?></a>
        </div>
      </div>

    </div>
  </div>
</div>

<?php
}

function get_search_by_area_id_url( $id ){

	$meta = get_post_custom( $id );
	$area_id = $meta[ 'staycity_area_id'][0];
	$latitude = $meta['staycity_gmap_latitude'][0];
	$longitude = $meta['staycity_gmap_longitude'][0];
	$zoom = str_replace ( 'z', '', $the_meta['staycity_gmap_zoom'][0] );

	$search_results = get_option( 'resortpro_listings_page_id' );
	$url = get_permalink( $search_results );

	$link = add_query_arg( array(
		'area_id'	=> $area_id,
		'latitude'	=> $latitude,
		'longitude'	=> $longitude,
		'zoom'		=> $zoom,
	), $url );

	return $link;
}

function stayalfred_get_cities( $field = NULL ) {
  // default
  $city_arr = array();

  // get city page
  $city_page = get_page_by_path( 'cities' );
  if ( is_null( $city_page ) )
    return $city_arr;

  // get city sub pages, ordered by menu order
  $city_arr = get_pages( array(
    'sort_column' => 'menu_order',
    'parent'      => $city_page->ID
  ) );

  $cities = new StayAlfred_Cities_Query( array(
  	'orderby'	=> 'menu_order',
  	'order'		=> 'ASC'
  ) );

  if( $cities->have_posts() && ! is_null( $field ) ){
  	return wp_list_pluck( $cities->posts, $field );
  } elseif( $cities->have_posts() ) {
  	return $cities->posts;
  } else {
  	return array();
  }

  if ( sizeof( $city_arr ) && $field ) {
    return wp_list_pluck( $city_arr, $field );
  } else {
    return $city_arr;
  }
}

function stayalfred_group_amenities( $raw_emenity_arr ) {
  // check raw emenities
  if ( ! sizeof( $raw_emenity_arr ) )
    return array();

  if ( array_key_exists( 'group_name' , $raw_emenity_arr ) ) {
    $raw_emenity_arr = array($raw_emenity_arr);
  }

  // default
  $amenity_arr = array();

  // group
  foreach ( $raw_emenity_arr as $e ) {
    if ( ! array_key_exists( $e['group_name'], $amenity_arr ) ) {
      $amenity_arr[$e['group_name']] = array();
    }
    $amenity_arr[$e['group_name']][] = $e;
  }

  // sort groupings
  ksort( $amenity_arr );

  // sort emenities
  foreach ( $amenity_arr as $grouping => $amenities ) {
    usort( $amenities, function( $e1, $e2 ) {
      return strcmp($e1['amenity_name'], $e2['amenity_name']);
    });
    $amenity_arr[$grouping] = $amenities;
  }

  return $amenity_arr;
}
