'use strict';

/*
 *    Packages and Settings
-------------------------------------------------- */

var gulp = require('gulp'),
	browserSync = require('browser-sync').create(),
	changed = require('gulp-changed'),
	cleancss = require('gulp-clean-css'),
	cssnano = require('gulp-cssnano'),
	deleted = require('gulp-deleted'),
	imagemin = require('gulp-imagemin'),
	plumber = require('gulp-plumber'),
	sass = require('gulp-sass'),
	sassGlob = require('gulp-sass-glob'),
	runSequence = require('run-sequence'),
	uglify = require('gulp-uglify'),
	util = require('gulp-util'),
	b = {
		css   :'./dist/public_html/wp-content/themes/stayalfred/assets/dist/css/',
		html  :'./dist/public_html/wp-content/themes/stayalfred/',
		js    :'./dist/public_html/wp-content/themes/stayalfred/assets/js/',
		media :'./dist/public_html/wp-content/themes/stayalfred/assets/'
	},
	s = {
		css   :'./src/styles/',
		html  :'./src/templates/',
		js    :'./src/scripts/',
		media :'./src/media/'
	};


/*
 *    Templates
-------------------------------------------------- */
gulp.task('processTemplates', function() {
	return gulp.src(s.html + '**/*.php')
		.pipe(plumber({
			errorHandler: function(err) {
				util.log(err);
				this.emit('end');
			}
		}))
		.pipe(deleted(b.html))
		.pipe(changed(b.html))
		.pipe(gulp.dest(b.html))
		.on('end', function() {
			util.log('--- Templates processed ------');
		});
});

/*
 *    Styles
-------------------------------------------------- */
gulp.task('processStyles', function() {
	return gulp.src(s.css + '*.scss')
		.pipe(plumber({
			errorHandler: function(err) {
				util.log(err);
				this.emit('end');
			}
		}))
		.pipe(sassGlob())
		.pipe(sass({
			includePaths :['./node_modules/'],
			outputStyle  :'compressed'
		}))
		.pipe(cleancss({
			level: {
				1 :{all: false},
				2 :{
					all        :false,
					mergeMedia :true
				}
			}
		}))
		.pipe(cssnano())
		.pipe(gulp.dest(b.css))
		.on('end', function() {
			util.log('--- Styles processed ------');
		});
});


/*
 *    Scripts
-------------------------------------------------- */
gulp.task('processScripts', function() {
	return gulp.src(s.js + '**/*.js')
		.pipe(plumber({
			errorHandler: function(err) {
				util.log(err);
				this.emit('end');
			}
		}))
		.pipe(uglify({ mangle: false }))
		.pipe(gulp.dest(b.js))
		.on('end', function() {
			util.log('--- Scripts processed ------');
		});
});

/*
 *    Media
-------------------------------------------------- */

/** --- Process Images --------- */
gulp.task('processImages', function() {
	return gulp.src(s.media + 'images/**/*')
		.pipe(plumber({
			errorHandler: function(err) {
				util.log(err);
				this.emit('end');
			}
		}))
		.pipe(deleted(b.media + 'images/'))
		.pipe(changed(b.media + 'images/'))
		.pipe(imagemin({ verbose: true }))
		.pipe(gulp.dest(b.media + 'images/'))
		.on('end', function() {
			util.log('--- Images processed ------');
		});
});



/*
 *    Watch
-------------------------------------------------- */
gulp.task('watch', function() {
	/** Start BrowserSync server */
	browserSync.init({
		ghostMode :false,
		https     :{
			cert :'./src/vault/certs/stayalfred.dev.crt',
			key  :'./src/vault/certs/stayalfred.dev.key'
		},
		open  :false,
		proxy :{
			target :'https://stayalfred.dev',
			ws     :true
		}
	});

	/** Templates */
	gulp.watch([s.html + '**/*.php'], ['processTemplates']);

	/** Styles */
	gulp.watch([s.css + '**/*.scss'], ['processStyles']);

	/** processScripts */
	gulp.watch([s.js + '**/*.js'], ['processScripts']);

	/** Images */
	gulp.watch([s.media + 'images/**/*'], ['processImages']);

	/** Live Reload */
	gulp.watch([b.html + '**/*.php', b.media + '**/*.{jpg,png,gif,svg}'])
		.on('change', browserSync.reload);

	gulp.watch([b.html + '**/*.{css,js}']).on('change', function(event) {
		return gulp.src(event.path).pipe(browserSync.stream());
	});
});



/*
 *    Tasks
-------------------------------------------------- */
gulp.task('default', ['build']);

gulp.task('build', function(callback) {
	runSequence('processTemplates',
		'processStyles',
		'processScripts',
		'processImages',
		'watch',
		callback);
});
