<?php
if ( ! class_exists( 'Stayalfred_Hero_Slider' ) ) {
  class Stayalfred_Hero_Slider{
    static protected $_this;
    protected $_settings_definition_arr = array();

    // construct
    function __construct() {
      // defaults
      $this->_settings_definition_arr['group'] = 'stayalfred-hero-slider-group';
			$this->_settings_definition_arr['options'] = 'stayalfred-hero-slider-options';

      // hooks
      add_action( 'admin_init', array( &$this, 'admin_init' ) );
      add_action( 'admin_menu', array( &$this, 'admin_menu' ) );
      add_action( 'admin_enqueue_scripts', array( &$this, 'admin_enqueue' ) );
      add_action( 'stayalfred-hero-slider', array( &$this, 'hero_slider' ) );
    }

    // admin init
    function admin_init() {
      register_setting($this->_settings_definition_arr['group'], $this->_settings_definition_arr['options']);
    }

    // admin menu
    function admin_menu() {
      add_submenu_page( 'themes.php', __( 'Hero Slider', 'stayalfred-theme' ), __( 'Hero Slider', 'stayalfred-theme' ), 'manage_options', 'stayalfred-hero-slider', array( & $this, 'admin_page' ) );
    }

    // admin enqueue scripts/styles
    function admin_enqueue( $hook ) {
      if ( $hook == 'appearance_page_stayalfred-hero-slider' ) {
        // media upload
        wp_enqueue_media();

        // jquery ui sortable
        wp_enqueue_script('jquery-ui-sortable');

        // hero slider
        wp_enqueue_script('stayalfred-hero-slider', get_template_directory_uri() . '/assets/' . ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? 'src/js/hero-slider.js' : 'dist/js/hero-slider.min.js' ), array( 'jquery', 'media-upload', 'thickbox' ) );
        wp_enqueue_style('stayalfred-hero-slider', get_template_directory_uri() . '/assets/' . ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? 'src/css/hero-slider.css' : 'dist/css/hero-slider.min.css' ) );
      }
    }

    // admin page
    function admin_page() {
      if ( $_POST )
        $status = $this->save_hero_slides();

      // get current hero slides
      $slide_arr = get_option( $this->_settings_definition_arr['options'] );
?>
  <div class="wrap">
    <h1>
      <?php _e( 'Hero Slider', 'stayalfred-theme' ) ?>
      <a href="javascript:void(0);" id="hero-slider-add-slide" class="page-title-action"><?php _e( 'Add New Slide', 'stayalfred-theme' ) ?></a>
    </h1>
    <?php if ( isset( $status ) ) : ?>
      <?php if ($status) : ?>
        <div class="notice notice-success"><p><?php _e( 'Hero slides successfully saved.', 'stayalfred-theme' ) ?></p></div>
      <?php else : ?>
        <div class="notice notice-error"><p><?php _e( 'There was an error saving your hero slides, please try again later.', 'stayalfred-theme' ) ?></p></div>
      <?php endif; ?>
    <?php endif; ?>
    <form method="POST">
      <table id="hero-slider-slides">
        <tbody>
          <?php if ( is_array( $slide_arr ) ) : ?>
            <?php foreach ( $slide_arr as $slide ) : ?>
              <tr>
                <td width="200">
                  <span class="dashicons dashicons-dismiss btn-hero-slider-delete-slide"></span>
                  <img src="<?php echo $slide['image'] ?>" />
                </td>
                <td>
                  <input type="hidden" name="slide-image[]" value="<?php echo $slide['image'] ?>" />
                  <textarea name="slide-content[]"><?php echo $slide['content'] ?></textarea>
                </td>
              </tr>
            <?php endforeach; ?>
          <?php endif; ?>
        </tbody>
      </table>
      <input type="submit" class="button button-primary" id="btn-hero-slider-save"<?php if ( ! is_array( $slide_arr ) || ! sizeof( $slide_arr ) ) : ?> style="display: none;"<?php endif; ?> value="Save Hero Slides" />
    </form>
  </div>
<?php
    }

    // save slides
    function save_hero_slides() {
      // get form data
      $slide_image_arr = $_POST['slide-image'];
      $slide_content_arr = $_POST['slide-content'];

      // check form data
      if ( ! is_array( $slide_image_arr ) || ! is_array( $slide_content_arr ) || sizeof( $slide_image_arr ) != sizeof( $slide_content_arr ) )
        return false;

      $slide_arr = array();
      if ( sizeof( $slide_image_arr ) ) {
        for ($i = 0; $i < sizeof( $slide_image_arr ); $i++ ) {
          $slide_arr[] = array(
            'image'   => sanitize_text_field( $slide_image_arr[ $i ] ),
            'content' => stripslashes( $slide_content_arr[ $i ] )
          );
        }
      }

      // save
      update_option( $this->_settings_definition_arr['options'], $slide_arr );

      return TRUE;
    }

    // hero slider
    function hero_slider() {
      // get slides
      $slide_arr = get_option( $this->_settings_definition_arr['options'] );

      // check that we have slides
      if ( ! is_array( $slide_arr ) || ! sizeof( $slide_arr ) )
        return;

?>
<div id="slider" class="carousel slide hero-slider" data-ride="carousel">
  <?php if( is_active_sidebar( 'home-hero-widgets' ) ) : ?>
    <?php dynamic_sidebar( 'home-hero-widgets' ) ?>
  <?php endif; ?>
  <div class="carousel-inner" role="listbox">
    <?php for ( $i = 0; $i < sizeof( $slide_arr ); $i++ ) : ?>
      <div class="item<?php if ( $i == 0 ) : ?> active<?php endif; ?>" style="background-image:url('<?php echo $slide_arr[$i]['image'] ?>');">
        <div class="hero-search">
          <div class="overlay-white"></div>
          <div class="table-it">
            <div class="cell-it">
              <div class="container<?php if ( $i == 0 ) : ?> container-special<?php endif; ?>">
                <div class="row">
                  <div class="search-box col-md-10 col-md-offset-1 center">
                    <?php echo $slide_arr[$i]['content'] ?>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    <?php endfor; ?>
  </div>

  <a class="left carousel-control" href="#slider" role="button" data-slide="prev">
    <i class="fa fa-angle-left"></i>
    <span class="sr-only"><?php _e( 'Previous', 'stayalfred' ) ?></span>
  </a>
  <a class="right carousel-control" href="#slider" role="button" data-slide="next">
    <i class="fa fa-angle-right"></i>
    <span class="sr-only"><?php _e( 'Next', 'stayalfred-theme' ) ?></span>
  </a>
</div>
<?php
    }

    // get instance
    static function get_instance() {
      if ( ! is_object( self::$_this ) ) {
        self::$_this = new self();
      }

      return self::$_this;
    }
  }

  Stayalfred_Hero_Slider::get_instance();
}
