<?php

/**
 *  Add the `special` post type.
 */
function add_specials_post_type() {
	$labels = array(
		'name' => 'Specials',
		'singular_name' => 'Special',
		'menu_name' => 'Specials',
		'add_new' => 'Add New',
		'add_new_item' => 'Add New Special',
		'edit' => 'Edit entry',
		'edit_item' => 'Edit Special',
		'new_item' => 'New Special',
		'view' => 'View Special',
		'view_item' => 'View Special',
		'search_items' => 'Search Specials',
		'not_found' => 'No Specials Found',
		'not_found_in_trash' => 'No Specials Found in Trash',
		'parent' => 'Parent Special',
	);

	register_post_type('specials', array(
			'label' => __( 'specials', 'specials' ),
			'description' => __( 'Specials', 'psp_projects' ),
			'labels' => $labels,
			'public' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'capability_type' => array('special','specials'),
      'map_meta_cap' => true,
			'menu_position' => 20,
			'has_archive' => false,
			'menu_icon' => get_template_directory_uri() . "/assets/images/icon-post-type-specials.png",
		)
	);
}

add_action('init', 'add_specials_post_type');



/** --- Load Cities ------ */
function acf_specials_load_cities($field) {
	$city_file = get_template_directory() . '/assets/json/specials-cities.json';
	if (file_exists($city_file)) {
		$city_json = file_get_contents($city_file, FILE_USE_INCLUDE_PATH);
		$cities = json_decode($city_json, true);
	} else {
		$cities = streamline_api('GetLocationAreasList', array());
		$cities = json_decode($cities, true)['data']['location_area'];
		$fp = fopen($city_file, 'w');
		fwrite($fp, json_encode($cities));
		fclose($fp);
	}
	$field['choices'] = array();
	foreach($cities as $city) {
		$val = $city['id'] . '_' . $city['name'];
		$field['choices'][$val] = $city['name'];
	}
	return $field;
}
add_filter('acf/load_field/name=promo_props_city', 'acf_specials_load_cities');






/** --- Load Buildings ------ */
function acf_specials_load_buildings($field) {
	/** Set up initial array for the <select> ($choices) and <option> ($buildings) */
	$field['choices'] = array();
	$buildings = array();
	$building_file = get_template_directory() . '/assets/json/specials-buildings.json';
	if (file_exists($building_file)) {
		$buildings_json = file_get_contents($building_file, FILE_USE_INCLUDE_PATH);
		$buildings = json_decode($buildings_json, true);
	} else {
		/** We don't. Hit the Streamline API for both buildings and cities data. */
		$buildings_raw = streamline_api('GetLocationsList', array());
		$cities_raw = streamline_api('GetLocationAreasList', array());

		/** Convert the returned JSON to associative arrays to make filtering easier. */
		$buildings_json = json_decode($buildings_raw, true)['data']['location'];
		$cities_json = json_decode($cities_raw, true)['data']['location_area'];


		/** To make things easier later, add the name of the city to the building array. */
		foreach($buildings_json as $building) {
			$key = array_search($building['location_area_id'], array_column($cities_json, 'id'));
			$city_name = $cities_json[$key]['name'];
			$building['location_area_name'] = $city_name;
			$buildings[] = $building;
		}

		$fp = fopen($building_file, 'w');
		fwrite($fp, json_encode($buildings));
		fclose($fp);
	}

	/** Populate the <select> field. We're using the city name as an <optgroup> to make things easier to find. */
	foreach ($buildings as $building) {
		$building_id = $building['id'];
		$building_name = $building['name'];
		$building_location_name = $building['location_area_name'];
		$building_location_id = $building['location_area_id'];
		/** Check to see if a city exists already. If it doesn't exist, then create an empty array. */
		if (!array_key_exists($building_location_name, $field['choices'])) {
			$field['choices'][$building_location_name] = array();
    }
		/** Populate the city with the building. */
		$field['choices'][$building_location_name] = $field['choices'][$building_location_name] + array(
			$building_location_id . '_' . $building_location_name . '|' . $building_id  . '_' . $building_name => $building_name
		);
	}

	return $field;
}
add_filter('acf/load_field/name=promo_props_building', 'acf_specials_load_buildings');


/** Working <optgroup>
* $field['choices']['New Jersey'] = array(
* 	'1234' => 'One',
* 	'4567' => 'Two'
* );
*/




/**
 *  8065 - Atlanta
 *  5171 - Nashville
 *  8044 - Chicago
 *  5157 - Boston
 */

function acf_specials_load_units($field) {
	/** Set up variables */
	$units = array();
	$field['choices'] = array();

	/** Get list of cities */
	$city_file = get_template_directory() . '/assets/json/specials-cities.json';
	if (file_exists($city_file)) {
		$city_json = file_get_contents($city_file, FILE_USE_INCLUDE_PATH);
		$cities = json_decode($city_json, true);
	} else {
		$cities = streamline_api('GetLocationAreasList', array());
		$cities = json_decode($cities, true)['data']['location_area'];
	}

	/** Go through each city and check for a JSON file. */
	foreach ($cities as $city) {
		$city_prop_file =  get_template_directory() . '/assets/json/specials-units-'. $city['id'] .'.json';
		if (file_exists($city_prop_file)) {
			$city_props_json = file_get_contents($city_prop_file, FILE_USE_INCLUDE_PATH);
			$city_props = json_decode($city_props_json, true);
			$units[] = $city_props;
		} else {
			$city_props_arr = array();
			$city_props_raw = streamline_api('GetPropertyListWordPress', array('location_area_id' => $city['id']));
			$city_props = json_decode($city_props_raw, true)['data']['property'];


			foreach ($city_props as $prop) {
				$city_id = $prop['location_area_id'];
				$city_name = $prop['location_area_name'];

				$building_name = $prop['location_name'];

				$unit_id = $prop['id'];
				$unit_name = $prop['seo_page_name'];

				if (gettype($unit_name) == 'string') {
					$pretty_name = str_replace('-', ' ', $unit_name);
					$city_props_arr = $city_props_arr + array(
						$city_id . '_' . $city_name . '|' . 'null_' . $building_name . '|' . $unit_id . '_' . $unit_name => $pretty_name
					);
				}
			}

			$city_props_master = array(
				$city['name'] => $city_props_arr
			);

			$units[] = $city_props_master;

			 $fp = fopen($city_prop_file, 'w');
			 fwrite($fp, json_encode($city_props_master));
			 fclose($fp);
		}
	}


	foreach ($units as $unit) {
		$field['choices'] = $field['choices'] + $unit;
	}

	return $field;

}

add_filter('acf/load_field/name=promo_props_unit', 'acf_specials_load_units');
