<?php

	get_header();

	function populate_building_info($prop) {
		return array(
			'name' => $prop['location_name'],
			'slug' => strtolower(str_replace(' ', '-', $prop['location_name'])),
			'lat' => $prop['location_latitude'],
			'lon' => $prop['location_longitude']
		);
	}

	/** Get current availability in Nashville June 07–10. */
	$nashville_data = streamline_api('GetPropertyAvailabilityWithRatesWordPress', array(
		'startdate' => '06/07/2018',
		'enddate' => '06/10/2018',
		'location_area_id' => '5171'
	));


	$properties = json_decode($nashville_data, true)['data']['available_properties']['property'];

	//dump($properties, true);
	$arr_cityview = array(
		"info" => array(),
		"units" => array()
	);
	$arr_thejames = array(
		"info" => array(),
		"units" => array()
	);
	$arr_fiveohfive = array(
		"info" => array(),
		"units" => array()
	);


	foreach($properties as $prop) {
		if (gettype($prop['seo_page_name']) === 'string') {
			switch($prop['location_name']) {
				case "City View":
					if (empty($arr_cityview['info'])) {
						$arr_cityview['info'] = populate_building_info($prop);
					}
        	array_push($arr_cityview['units'], $prop);
        	break;
				case "The James":
					if (empty($arr_thejames['info'])) {
						$arr_thejames['info'] = populate_building_info($prop);
					}
	      	array_push($arr_thejames['units'], $prop);
	      	break;
				case "505":
					if (empty($arr_fiveohfive['info'])) {
						$arr_fiveohfive['info'] = populate_building_info($prop);
					}
        	array_push($arr_fiveohfive['units'], $prop);
        	break;
				case 505:
					if (empty($arr_fiveohfive['info'])) {
						$arr_fiveohfive['info'] = populate_building_info($prop);
					}
        	array_push($arr_fiveohfive['units'], $prop);
        	break;
			}
		}
	}

	$arr_master = array(
		"505" => $arr_fiveohfive,
		"thejames" => $arr_thejames,
		"cityview" => $arr_cityview
	);
?>

	<link rel="stylesheet" href="<?php echo get_template_directory_uri();?>/assets/dist/css/style-cma.css">
	<script src="//maps.google.com/maps/api/js?sensor=true&key=AIzaSyBaXwGEbiUKpibZse5Rl1gBddiaXymyqZ8" type="text/javascript"></script>
	<script src="<?php echo get_template_directory_uri();?>/assets/js/cma.js" type="text/javascript"></script>


	<section class="cma-2018">

		<!-- MASTHEAD -->
		<div class="masthead">
			<div class="container">
				<div class="row">
					<div class="col-md-12">
						<h1>Stay Just Steps from the CMA Stages</h1>
					</div>
				</div>
			</div>
		</div>

		<!-- MAP -->
		<div class="gmap">
			<div class="gmap-canvas">
				<div id="map_div"></div>
			</div>
		</div>

		<!-- CONTENT -->
		<div class="content">
			<div class="container">
				<div class="row">
					<div class="col-md-12">
						<p>Perfect for out-of-towners and 615-ers alike, our Downtown Nashville Stay Alfreds are the perfect home base during CMA Music Festival weekend.</p>
					</div>
				</div>
			</div>
		</div>


		<!-- FOREACH BUILDING -->
		<div class="properties">
			<div class="container">
				<h2 class="headline">Currently Available:<br>Stay Alfreds in Downtown Nashville</h2>
				<?php foreach($arr_master as $building): ?>
				<div class="row" id="<?php echo $building['info']['slug']; ?>">

					<section class="building col-md-12">
						<h2 class="building-name"><?php echo $building['info']['name']; ?></h2>
						<?php foreach($building['units'] as $unit): ?>
							<?php
								$url = '/' . $unit['seo_page_name'];
								$name = str_replace('-', ' ', $unit['seo_page_name']);
								$img = $unit['default_thumbnail_path'];
								$price = $unit['price'];
								$bed = $unit['bedrooms_number'];
								$bath = $unit['bathrooms_number'];
								$occupants = $unit['max_occupants'];
							?>
							<article class="prop-card col-12 col-md-4">
								<a href="<?php echo $url; ?>">
									<!-- Image -->
									<img src="<?php echo $img; ?>">
									<div class="prop-card-info">
										<h4 class="prop-card-city">Nashville, TN</h4>
										<h2 class="prop-card-title"><?php echo $name; ?></h2>
										<h5 class="prop-card-price">
											<span class="word">from</span>
											<span class="num">$<?php echo trim(round($price / 3)); ?></span>
											<span class="word">per night</span>
										</h5>
										<h5 class="prop-card-price">
											<span class="word" style="margin-top: 12px;">Max occupants: <?php echo $occupants; ?></span>
										</h5>
									</div>
								</a>
							</article>
						<?php endforeach; ?>
					</section>
				</div>
				<?php endforeach; ?>
			</div>
		</div>

		<!-- CONTENT 2 -->
		<div class="content">
			<div class="container">
				<div class="row">
					<div class="col-md-12">
						<?php echo the_content(); ?>
					</div>
				</div>
			</div>
		</div>

		<!-- CTA -->
		<div class="blog-cta">
			<div class="container">
				<div class="row">
					<div class="col-12 col-md-5">
						<h3>Never been to the <span>CMA Music Fest</span>?</h3>
					</div>
					<div class="blog-cta-content col-12 col-md-7">
						<p>Check out our <a href="/cma-fest-survival-guide">Survival Guide</a> for a complete list of<br>Yeehaws and Hell Nahs.</p>
						<a class="button" href="/cma-fest-survival-guide">Nashville Survival Guide</a>
					</div>
				</div>
			</div>
		</div>

	</section>


<?php get_footer() ?>
